@@ -26,19 +26,20 @@
 This module contains a Distribution subclass (GDistribution) which
 implements build and install commands for operations related to
 Python GTK+ and GObject support. This includes installation
-of man pages and gettext/intltool support.
+of man pages and gettext support.
 
 Also supports setuptools but needs to be imported after setuptools
 (which does some monkey patching)
 """
 
+import os
 import sys
 
 from distutils.core import setup
 
 from .shortcuts import build_shortcuts, install_shortcuts
 from .man import install_man
-from .po import build_mo, install_mo, po_stats, update_po, create_po
+from .po import build_mo, install_mo, po_stats, update_po, create_po, build_po
 from .icons import install_icons
 from .search_provider import install_search_provider
 from .dbus_services import build_dbus_services, install_dbus_services
@@ -61,6 +62,8 @@ class build(distutils_build):
     sub_commands = distutils_build.sub_commands + [
         ("build_mo",
          lambda self: self.distribution.has_po()),
+        ("build_po",
+         lambda self: self.distribution.has_po()),
         ("build_shortcuts",
          lambda self: self.distribution.has_shortcuts()),
         ("build_dbus_services",
@@ -118,7 +121,7 @@ class GDistribution(Distribution):
       man_pages -- list of man pages to install
       appdata -- list of appdata files to install
 
-    Using the translation features requires intltool.
+    Using the translation features requires gettext.
 
     Example:
       from distutils.core import setup
@@ -139,6 +142,7 @@ class GDistribution(Distribution):
 
     def __init__(self, *args, **kwargs):
         Distribution.__init__(self, *args, **kwargs)
+        self.cmdclass.setdefault("build_po", build_po)
         self.cmdclass.setdefault("build_mo", build_mo)
         self.cmdclass.setdefault("build_shortcuts", build_shortcuts)
         self.cmdclass.setdefault("build_dbus_services", build_dbus_services)
@@ -175,6 +179,10 @@ class GDistribution(Distribution):
         return not is_osx and bool(self.shortcuts)
 
     def has_appdata(self):
+        if os.name == "nt":
+            # Translation merge is broken atm due to:
+            # https://github.com/Alexpux/MINGW-packages/issues/4392
+            return False
         return not is_osx and bool(self.appdata)
 
     def has_man_pages(self):
