@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2007 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2009-2010 Steven Robertson
-#      2012,2013,2016 Nick Boultbee
+#           2012-2018 Nick Boultbee
 #           2009-2014 Christoph Reiter
+#           2018      Uriel Zajaczkovski
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from __future__ import absolute_import
 
@@ -38,12 +40,11 @@ from quodlibet.qltk.x import SymbolicIconImage
 from quodlibet.qltk.searchbar import SearchBarBox
 from quodlibet.qltk.menubutton import MenuButton
 from quodlibet.qltk import Icons
-from quodlibet.util import copool, connect_destroy
+from quodlibet.util import copool, connect_destroy, cmp
 from quodlibet.util.library import background_filter
-from quodlibet.util import connect_obj, DeferredSignal, gdecode
+from quodlibet.util import connect_obj, DeferredSignal
 from quodlibet.qltk.cover import get_no_cover_pixbuf
 from quodlibet.qltk.image import add_border_widget, get_surface_for_pixbuf
-from quodlibet.compat import cmp
 
 
 def get_cover_size():
@@ -160,6 +161,22 @@ def compare_rating(a1, a2):
             cmp(a1.key, a2.key))
 
 
+def compare_avgplaycount(a1, a2):
+    a1, a2 = a1.album, a2.album
+    if a1 is None:
+        return -1
+    if a2 is None:
+        return 1
+    if not a1.title:
+        return 1
+    if not a2.title:
+        return -1
+    return (-cmp(a1("~#playcount:avg"), a2("~#playcount:avg")) or
+            cmpa(a1.date, a2.date) or
+            cmpa(a1.sort, a2.sort) or
+            cmp(a1.key, a2.key))
+
+
 class PreferencesButton(Gtk.HBox):
     def __init__(self, browser, model):
         super(PreferencesButton, self).__init__()
@@ -170,6 +187,7 @@ class PreferencesButton(Gtk.HBox):
             (_("_Date"), self.__compare_date),
             (_("_Genre"), self.__compare_genre),
             (_("_Rating"), self.__compare_rating),
+            (_("_Playcount"), self.__compare_avgplaycount),
         ]
 
         menu = Gtk.Menu()
@@ -233,6 +251,10 @@ class PreferencesButton(Gtk.HBox):
         a1, a2 = model.get_value(i1), model.get_value(i2)
         return compare_rating(a1, a2)
 
+    def __compare_avgplaycount(self, model, i1, i2, data):
+        a1, a2 = model.get_value(i1), model.get_value(i2)
+        return compare_avgplaycount(a1, a2)
+
 
 class VisibleUpdate(object):
 
@@ -416,7 +438,7 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
         if self.__model is None:
             self._init_model(library)
 
-        self._cover_cancel = Gio.Cancellable.new()
+        self._cover_cancel = Gio.Cancellable()
 
         sw = ScrolledWindow()
         sw.set_shadow_type(Gtk.ShadowType.IN)
@@ -545,6 +567,9 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
                 window = Information(librarian, songs, self)
                 window.show()
             return True
+        elif qltk.is_accel(event, "<Primary>Return", "<Primary>KP_Enter"):
+            qltk.enqueue(self.__get_selected_songs(sort=True))
+            return True
         elif qltk.is_accel(event, "<alt>Return"):
             songs = self.__get_selected_songs()
             if songs:
@@ -589,8 +614,9 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
         model = self.view.get_model()
 
         self.__filter = None
-        if not Query.match_all(text):
-            self.__filter = Query(text, star=["~people", "album"]).search
+        query = self.__search.get_query(star=["~people", "album"])
+        if not query.matches_all:
+            self.__filter = query.search
         self.__bg_filter = background_filter()
 
         self.__inhibit()
@@ -628,7 +654,7 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
         album = model.get_album(iter_)
         if album is None:
             return True
-        key = gdecode(key).lower()
+        key = key.lower()
         title = album.title.lower()
         if key in title:
             return False
@@ -712,7 +738,7 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
 
     def filter_text(self, text):
         self.__search.set_text(text)
-        if Query.is_parsable(text):
+        if Query(text).is_parsable:
             self.__update_filter(self.__search, text)
             self.__inhibit()
             self.view.set_cursor((0,))
@@ -764,7 +790,7 @@ class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
         entry.set_text(text)
 
         # update_filter expects a parsable query
-        if Query.is_parsable(text):
+        if Query(text).is_parsable:
             self.__update_filter(entry, text, scroll_up=False, restore=True)
 
         keys = config.gettext("browsers", "albums").split("\n")
