@@ -2,16 +2,19 @@
 # Copyright 2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import operator
 
 from gi.repository import Gtk, Pango, Gdk
 
 from quodlibet import qltk
-from quodlibet.qltk.views import AllTreeView, TreeViewColumn
+from quodlibet.qltk.views import AllTreeView, TreeViewColumnButton
 from quodlibet.qltk.songsmenu import SongsMenu
+from quodlibet.qltk.properties import SongProperties
+from quodlibet.qltk.information import Information
 from quodlibet.qltk import is_accel
 from quodlibet.util import connect_obj
 
@@ -35,7 +38,18 @@ class Pane(AllTreeView):
 
         self.__no_fill = 0
 
-        column = TreeViewColumn(self.config.title)
+        column = TreeViewColumnButton(title=self.config.title)
+
+        def on_column_header_clicked(column, event):
+            # In case the column header gets clicked select the "All" entry
+            if event.button != Gdk.BUTTON_PRIMARY or \
+                    event.type != Gdk.EventType.BUTTON_PRESS:
+                return Gdk.EVENT_PROPAGATE
+            self.set_selected([])
+            return Gdk.EVENT_STOP
+
+        column.set_clickable(True)
+        column.connect("button-press-event", on_column_header_clicked)
         column.set_use_markup(True)
         column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
         column.set_fixed_width(50)
@@ -78,7 +92,8 @@ class Pane(AllTreeView):
 
         selection = self.get_selection()
         selection.set_mode(Gtk.SelectionMode.MULTIPLE)
-        self.__sig = selection.connect('changed', self.__selection_changed)
+        self.__sig = self.connect(
+            'selection-changed', self.__selection_changed)
         s = self.connect('popup-menu', self.__popup_menu, library)
         connect_obj(self, 'destroy', self.disconnect, s)
 
@@ -94,20 +109,36 @@ class Pane(AllTreeView):
         self.connect("drag-data-get", self.__drag_data_get)
         self.connect("destroy", self.__destroy)
 
-        self.connect("key-press-event", self.__key_pressed)
+        librarian = library.librarian or library
+        self.connect("key-press-event", self.__key_pressed, librarian)
 
-    def __key_pressed(self, view, event):
+    def __key_pressed(self, view, event, librarian):
         # if ctrl+a is pressed, intercept and select the All entry instead
         if is_accel(event, "<Primary>a"):
             self.set_selected([])
             return True
+        elif is_accel(event, "<Primary>Return", "<Primary>KP_Enter"):
+            qltk.enqueue(self.__get_selected_songs(sort=True))
+            return True
+        elif is_accel(event, "<alt>Return"):
+            songs = self.__get_selected_songs(sort=True)
+            if songs:
+                window = SongProperties(librarian, songs, parent=self)
+                window.show()
+            return True
+        elif is_accel(event, "<Primary>I"):
+            songs = self.__get_selected_songs(sort=True)
+            if songs:
+                window = Information(librarian, songs, self)
+                window.show()
+            return True
         return False
 
     def __repr__(self):
         return "<%s config=%r>" % (type(self).__name__, self.config)
 
     def parse_restore_string(self, config_value):
-        assert isinstance(config_value, unicode)
+        assert isinstance(config_value, str)
 
         values = config_value.split("\t")[:-1]
 
@@ -150,7 +181,7 @@ class Pane(AllTreeView):
 
     def __search_func(self, model, column, key, iter_, data):
         entry = model.get_value(iter_)
-        return not entry.contains_text(key.decode('utf-8'))
+        return not entry.contains_text(key)
 
     def __drag_data_get(self, view, ctx, sel, tid, etime):
         songs = self.__get_selected_songs(sort=True)
@@ -191,12 +222,12 @@ class Pane(AllTreeView):
         """Inhibit selection change events and song propagation"""
 
         self.__no_fill += 1
-        self.get_selection().handler_block(self.__sig)
+        self.handler_block(self.__sig)
 
     def uninhibit(self):
         """Uninhibit selection change events and song propagation"""
 
-        self.get_selection().handler_unblock(self.__sig)
+        self.handler_unblock(self.__sig)
         self.__no_fill -= 1
 
     def fill(self, songs):
