@@ -6,11 +6,13 @@
 #                 (C) 2004 Gustavo J. A. M. Carneiro
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of version 2 of the GNU General Public License as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk, Gdk
 
+from quodlibet import _
 from quodlibet import app
 from quodlibet import qltk
 from quodlibet.util import connect_obj
@@ -78,9 +80,9 @@ class AnimOsdPrefs(Gtk.VBox):
             self.Conf.monitor = value
             show_preview()
 
-        def change_position(button):
-            value = button.get_active() / 2.0
-            self.Conf.pos_y = value
+        def change_position(button, x, y):
+            self.Conf.pos_x = x / 2.0
+            self.Conf.pos_y = y / 2.0
             show_preview()
 
         def change_align(button):
@@ -135,7 +137,7 @@ class AnimOsdPrefs(Gtk.VBox):
             monitor_cnt = Gdk.Screen.get_default().get_n_monitors()
             if monitor_cnt > 1:
                 adj = Gtk.Adjustment(value=self.Conf.monitor, lower=0,
-                                     upper=monitor_cnt - 1, step_incr=1)
+                                     upper=monitor_cnt - 1, step_increment=1)
                 monitor = Gtk.SpinButton(adjustment=adj)
                 monitor.set_numeric(True)
                 monitor.connect('value-changed', change_monitor)
@@ -148,22 +150,40 @@ class AnimOsdPrefs(Gtk.VBox):
                 self.Conf.monitor = 0
 
             hb = Gtk.HBox(spacing=6)
-            cb = Gtk.ComboBoxText()
-            cb.append_text(_("Top of screen"))
-            cb.append_text(_("Middle of screen"))
-            cb.append_text(_("Bottom of screen"))
-            cb.set_active(int(self.Conf.pos_y * 2.0))
-            cb.connect('changed', change_position)
-            lbl = ConfigLabel(_("_Position:"), cb)
+            grid = Gtk.Grid(column_homogeneous=True,
+                            row_homogeneous=True,
+                            row_spacing=4,
+                            column_spacing=4)
+            arrows = [['↖', '↑', '↗'],
+                      ['←', '○', '→'],
+                      ['↙', '↓', '↘ ']]
 
+            group = None
+            for x in range(3):
+                for y in range(3):
+                    rb = Gtk.RadioButton(group=group, label=arrows[y][x])
+                    if (int(self.Conf.pos_x * 2.0) == x and
+                            int(self.Conf.pos_y * 2.0) == y):
+                        rb.set_active(True)
+                    grid.attach(rb, x, y, 1, 1)
+                    group = rb
+
+            # Connect to signal after the correct radio button has been
+            # selected
+            for x in range(3):
+                for y in range(3):
+                    rb = grid.get_child_at(x, y)
+                    rb.connect('toggled', change_position, x, y)
+
+            lbl = ConfigLabel(_("_Position:"), grid)
             hb.pack_start(lbl, False, True, 0)
-            hb.pack_start(cb, False, True, 0)
-            vb2.pack_start(hb, False, True, 0)
+            hb.pack_start(grid, False, True, 0)
+            vb2.pack_start(hb, False, True, 6)
 
             hb = Gtk.HBox(spacing=6)
             coversize = Gtk.SpinButton(
                 adjustment=Gtk.Adjustment.new(
-                    self.Conf.coversize, 120, 600, 1, 10, 0),
+                    self.Conf.coversize, 1, 600, 1, 10, 0),
                 climb_rate=1, digits=0)
             coversize.set_numeric(True)
             coversize.connect('value-changed', change_coversize)
