@@ -2,11 +2,12 @@
 # Copyright 2014 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from quodlibet.formats import AudioFile
-from quodlibet.util.dprint import print_d
+from quodlibet import print_d, ngettext, _
 
 from quodlibet import qltk
 
