@@ -3,11 +3,13 @@
 #           2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import mutagen.apev2
 
+from quodlibet import _
 from quodlibet.formats import AudioFileError
 from quodlibet.formats._apev2 import APEv2File
 from quodlibet.plugins.songshelpers import each_song, is_writable
