@@ -2,8 +2,9 @@
 # Copyright 2012-2017 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -11,7 +12,7 @@ import os
 
 from quodlibet.util.songwrapper import SongWrapper
 
-from quodlibet.qltk.songsmenu import ConfirmMultiSongInvoke
+from quodlibet.qltk.songsmenu import confirm_multi_song_invoke
 
 import quodlibet
 from quodlibet import _
@@ -147,7 +148,9 @@ class CustomCommands(PlaylistPlugin, SongsMenuPlugin, PluginConfigMixin):
         Command(name="Flash notification",
                 command="notify-send"
                     " -t 2000"
-                    " -i /usr/share/icons/hicolor/scalable/apps/quodlibet.svg",
+                    " -i "
+                        "/usr/share/icons/hicolor/scalable/apps/"
+                        "io.github.quodlibet.QuodLibet.svg",
                 pattern="<~rating> \"<title><version| (<version>)>\""
                         "<~people| by <~people>>"
                     "<album|, from <album><discnumber| : disk <discnumber>>"
@@ -215,7 +218,7 @@ class CustomCommands(PlaylistPlugin, SongsMenuPlugin, PluginConfigMixin):
         print_d("Loading saved commands from '%s'..." % filename)
         coms = None
         try:
-            with open(filename) as f:
+            with open(filename, "r", encoding="utf-8") as f:
                 coms = JSONObjectDict.from_json(Command, f.read())
         except (IOError, ValueError) as e:
             print_w("Couldn't parse saved commands (%s)" % e)
@@ -267,7 +270,7 @@ class CustomCommands(PlaylistPlugin, SongsMenuPlugin, PluginConfigMixin):
         if self.com_index:
             com = self.get_data(self.com_index)
             if len(songs) > com.warn_threshold:
-                if not ConfirmMultiSongInvoke.confirm(
+                if not confirm_multi_song_invoke(
                         self, com.name, len(songs)):
                     print_d("User decided not to run on %d songs" % len(songs))
                     return
@@ -280,6 +283,6 @@ class CustomCommands(PlaylistPlugin, SongsMenuPlugin, PluginConfigMixin):
                 print_exc()
                 ErrorMessage(
                     self.plugin_window,
-                    _("Unable to run custom command %s" %
-                      util.escape(self.com_index)),
+                    _("Unable to run custom command %s") %
+                    util.escape(self.com_index),
                     util.escape(str(err))).run()
