@@ -2,8 +2,9 @@
 # Copyright 2004-2006 Joe Wreschnig, Michael Urman, Niklas Janlert
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from mutagen.trueaudio import TrueAudio
 
@@ -17,6 +18,7 @@ class TrueAudioFile(ID3File):
 
     def _parse_info(self, info):
         self["~#length"] = info.length
+        self["~#samplerate"] = info.sample_rate
 
 loader = TrueAudioFile
 types = [TrueAudioFile]
