@@ -1,27 +1,26 @@
+# -*- coding: utf-8 -*-
 # Copyright 2006 Lukas Lalinsky
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import struct
 
-from quodlibet.util.path import get_temp_cover_file
-from quodlibet.formats._audio import AudioFile
-from quodlibet.formats._image import EmbeddedImage, APICType
+import mutagen.asf
 
-extensions = [".wma"]
-try:
-    import mutagen.asf
-except ImportError:
-    extensions = []
+from quodlibet.util.path import get_temp_cover_file
+
+from ._audio import AudioFile
+from ._image import EmbeddedImage, APICType
+from ._misc import AudioFileError, translate_errors
 
 
 class WMAFile(AudioFile):
-    multiple_values = False
     mimes = ["audio/x-ms-wma", "audio/x-ms-wmv", "video/x-ms-asf",
              "audio/x-wma", "video/x-wmv"]
-    format = "Windows Media Audio"
+    format = "ASF"
 
     #http://msdn.microsoft.com/en-us/library/dd743066%28VS.85%29.aspx
     #http://msdn.microsoft.com/en-us/library/dd743063%28VS.85%29.aspx
@@ -46,28 +45,74 @@ class WMAFile(AudioFile):
         "WM/Mood": "mood",
         "WM/EncodedBy": "encodedby",
         "MusicBrainz/Track Id": "musicbrainz_trackid",
+        "MusicBrainz/Release Track Id": "musicbrainz_releasetrackid",
         "MusicBrainz/Album Id": "musicbrainz_albumid",
         "MusicBrainz/Artist Id": "musicbrainz_artistid",
         "MusicBrainz/Album Artist Id": "musicbrainz_albumartistid",
         "MusicBrainz/TRM Id": "musicbrainz_trmid",
         "MusicIP/PUID": "musicip_puid",
+        "MusicBrainz/Release Group Id": "musicbrainz_releasegroupid",
         "WM/Year": "date",
         "WM/OriginalArtist": "originalartist",
         "WM/OriginalAlbumTitle": "originalalbum",
         "WM/AlbumSortOrder": "albumsort",
         "WM/ArtistSortOrder": "artistsort",
+        "WM/AlbumArtistSortOrder": "albumartistsort",
         "WM/Genre": "genre",
         "WM/Publisher": "publisher",
         "WM/AuthorURL": "website",
         "Description": "comment"
     }
-    __rtranslate = dict([(v, k) for k, v in __translate.iteritems()])
+    __rtranslate = dict([(v, k) for k, v in __translate.items()])
+
+    # http://msdn.microsoft.com/en-us/library/dd743065.aspx
+    # note: not all names here are used by QL
+    __multi_value_attr = {
+        "Author",
+        "WM/AlbumArtist",
+        "WM/AlbumCoverURL",
+        "WM/Category",
+        "WM/Composer",
+        "WM/Conductor",
+        "WM/Director",
+        "WM/Genre",
+        "WM/GenreID",
+        "WM/Language",
+        "WM/Lyrics_Synchronised",
+        "WM/Mood",
+        "WM/Picture",
+        "WM/Producer",
+        "WM/PromotionURL",
+        "WM/UserWebURL",
+        "WM/Writer",
+    }
+
+    __multi_value_keys = set()
+    for k, v in __translate.items():
+        if k in __multi_value_attr:
+            __multi_value_keys.add(v)
 
     def __init__(self, filename, audio=None):
         if audio is None:
-            audio = mutagen.asf.ASF(filename)
-        self["~#length"] = int(audio.info.length)
-        self["~#bitrate"] = int(audio.info.bitrate / 1000)
+            with translate_errors():
+                audio = mutagen.asf.ASF(filename)
+        info = audio.info
+
+        self["~#length"] = info.length
+        self["~#bitrate"] = int(info.bitrate / 1000)
+        if info.channels:
+            self["~#channels"] = info.channels
+        self["~#samplerate"] = info.sample_rate
+
+        type_, name, desc = info.codec_type, info.codec_name, \
+            info.codec_description
+
+        if type_:
+            self["~codec"] = type_
+        encoding = u"\n".join(filter(None, [name, desc]))
+        if encoding:
+            self["~encoding"] = encoding
+
         for name, values in audio.tags.items():
             if name == "WM/Picture":
                 self.has_images = True
@@ -75,11 +120,12 @@ class WMAFile(AudioFile):
                 name = self.__translate[name]
             except KeyError:
                 continue
-            self[name] = "\n".join(map(unicode, values))
+            self[name] = u"\n".join(map(str, values))
         self.sanitize(filename)
 
     def write(self):
-        audio = mutagen.asf.ASF(self["~filename"])
+        with translate_errors():
+            audio = mutagen.asf.ASF(self["~filename"])
         for key in self.__translate.keys():
             try:
                 del(audio[key])
@@ -92,9 +138,15 @@ class WMAFile(AudioFile):
             except KeyError:
                 continue
             audio.tags[name] = self.list(key)
-        audio.save()
+        with translate_errors():
+            audio.save()
         self.sanitize()
 
+    def can_multiple_values(self, key=None):
+        if key is None:
+            return self.__multi_value_keys
+        return key in self.__multi_value_keys
+
     def can_change(self, key=None):
         OK = self.__rtranslate.keys()
         if key is None:
@@ -143,28 +195,23 @@ class WMAFile(AudioFile):
     def clear_images(self):
         """Delete all embedded images"""
 
-        try:
+        with translate_errors():
             tag = mutagen.asf.ASF(self["~filename"])
-        except Exception:
-            return
-
-        tag.pop("WM/Picture", None)
-        tag.save()
+            tag.pop("WM/Picture", None)
+            tag.save()
 
         self.has_images = False
 
     def set_image(self, image):
         """Replaces all embedded images by the passed image"""
 
-        try:
+        with translate_errors():
             tag = mutagen.asf.ASF(self["~filename"])
-        except Exception:
-            return
 
         try:
-            imagedata = image.file.read()
-        except EnvironmentError:
-            return
+            imagedata = image.read()
+        except EnvironmentError as e:
+            raise AudioFileError(e)
 
         # thumbnail gets used in WMP..
         data = pack_image(image.mime_type, u"thumbnail",
@@ -172,7 +219,9 @@ class WMAFile(AudioFile):
 
         value = mutagen.asf.ASFValue(data, mutagen.asf.BYTEARRAY)
         tag["WM/Picture"] = [value]
-        tag.save()
+
+        with translate_errors():
+            tag.save()
 
         self.has_images = True
 
@@ -196,10 +245,10 @@ def unpack_image(data):
         raise ValueError(e)
     data = data[5:]
 
-    mime = ""
+    mime = b""
     while data:
         char, data = data[:2], data[2:]
-        if char == "\x00\x00":
+        if char == b"\x00\x00":
             break
         mime += char
     else:
@@ -207,10 +256,10 @@ def unpack_image(data):
 
     mime = mime.decode("utf-16-le")
 
-    description = ""
+    description = b""
     while data:
         char, data = data[:2], data[2:]
-        if char == "\x00\x00":
+        if char == b"\x00\x00":
             break
         description += char
     else:
@@ -229,12 +278,13 @@ def pack_image(mime, description, imagedata, type_):
 
     size = len(imagedata)
     data = struct.pack("<bi", type_, size)
-    data += mime.encode("utf-16-le") + "\x00\x00"
-    data += description.encode("utf-16-le") + "\x00\x00"
+    data += mime.encode("utf-16-le") + b"\x00\x00"
+    data += description.encode("utf-16-le") + b"\x00\x00"
     data += imagedata
 
     return data
 
 
-info = WMAFile
+loader = WMAFile
 types = [WMAFile]
+extensions = [".wma", ".asf", ".wmv"]
