@@ -4,8 +4,10 @@
 #           2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
 """
 Librarians for libraries.
 """
@@ -15,7 +17,6 @@ import itertools
 from gi.repository import GObject
 
 from quodlibet.util.dprint import print_d
-from quodlibet.compat import itervalues
 
 
 class Librarian(GObject.GObject):
@@ -82,14 +83,14 @@ class Librarian(GObject.GObject):
     def changed(self, items):
         """Triage the items and inform their real libraries."""
 
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             in_library = set(item for item in items if item in library)
             if in_library:
                 library._changed(in_library)
 
     def __getitem__(self, key):
         """Find a item given its key."""
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             try:
                 return library[key]
             except KeyError:
@@ -105,12 +106,12 @@ class Librarian(GObject.GObject):
 
     def remove(self, items):
         """Remove items from all libraries."""
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             library.remove(items)
 
     def __contains__(self, item):
         """Check if a key or item is in the library."""
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             if item in library:
                 return True
         else:
@@ -118,7 +119,7 @@ class Librarian(GObject.GObject):
 
     def __iter__(self):
         """Iterate over all items in all libraries."""
-        return itertools.chain(*itervalues(self.libraries))
+        return itertools.chain(*self.libraries.values())
 
     def move(self, items, from_, to):
         """Move items from one library to another.
@@ -142,7 +143,7 @@ class SongLibrarian(Librarian):
 
     def tag_values(self, tag):
         """Return a set of all values for the given tag."""
-        return {value for lib in self.libraries.itervalues()
+        return {value for lib in self.libraries.values()
                 for value in lib.tag_values(tag)}
 
     def rename(self, song, newname, changed=None):
@@ -158,7 +159,7 @@ class SongLibrarian(Librarian):
         # changed. So, it needs to reimplement the method.
         re_add = []
         print_d("Renaming %r to %r" % (song.key, newname), self)
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             try:
                 del library._contents[song.key]
             except KeyError:
@@ -185,7 +186,7 @@ class SongLibrarian(Librarian):
 
         had_item = []
         print_d("Reloading %r" % item.key, self)
-        for library in itervalues(self.libraries):
+        for library in self.libraries.values():
             try:
                 del library._contents[item.key]
             except KeyError:
