@@ -22,8 +22,8 @@ from quodlibet.util import is_windows
 def _get_chooser(accept_label, cancel_label):
     """
     Args:
-        accept_label (text_type)
-        cancel_label (text_type)
+        accept_label (str)
+        cancel_label (str)
     Returns:
         Gtk.FileChooser
     """
@@ -161,7 +161,7 @@ def create_chooser_filter(name, patterns):
     """Create a Gtk.FileFilter that also works on Windows
 
     Args:
-        name (text_type): The name of the filter
+        name (str): The name of the filter
         patterns (List[pathlike]): A list of glob patterns
     Returns:
         Gtk.FileFilter
@@ -180,8 +180,8 @@ def choose_folders(parent, title, action_title):
 
     Args:
         parent (Gtk.Widget)
-        title (text_type): The window title
-        action_title (text_type): The button title
+        title (str): The window title
+        action_title (str): The button title
     Returns:
         List[fsnative]
     """
@@ -200,8 +200,8 @@ def choose_files(parent, title, action_title, filter_=None):
 
     Args:
         parent (Gtk.Widget)
-        title (text_type): The window title
-        action_title (text_type): The button title
+        title (str): The window title
+        action_title (str): The button title
         filter_ (Gtk.FileFilter or None)
     Returns:
         List[fsnative]
@@ -224,9 +224,9 @@ def choose_target_file(parent, title, action_title, name_suggestion=None):
 
     Args:
         parent (Gtk.Widget)
-        title (text_type): The window title
-        action_title (text_type): The button title
-        name_suggestion (text_type): The suggested file name (not fsnative)
+        title (str): The window title
+        action_title (str): The button title
+        name_suggestion (str): The suggested file name (not fsnative)
     Returns:
         fsnative or None
     """
@@ -248,9 +248,9 @@ def choose_target_folder(parent, title, action_title, name_suggestion=None):
 
     Args:
         parent (Gtk.Widget)
-        title (text_type): The window title
-        action_title (text_type): The button title
-        name_suggestion (text_type): The suggested folder name (not fsnative)
+        title (str): The window title
+        action_title (str): The button title
+        name_suggestion (str): The suggested folder name (not fsnative)
     Returns:
         fsnative or None
     """
