@@ -2,17 +2,18 @@
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
-from quodlibet.compat import urlsplit
 import errno
+from urllib.parse import urlsplit
 
 from gi.repository import Gtk, GObject, Gdk, Gio, Pango
 from senf import uri2fsn, fsnative, fsn2text, bytes2fsn
 
-from quodlibet import formats
+from quodlibet import formats, print_d
 from quodlibet import qltk
 from quodlibet import _
 
@@ -24,9 +25,8 @@ from quodlibet.qltk.views import TreeViewColumn
 from quodlibet.qltk.x import ScrolledWindow, Paned
 from quodlibet.qltk.models import ObjectStore, ObjectTreeStore
 from quodlibet.qltk import Icons
-from quodlibet.compat import xrange
 from quodlibet.util.path import listdir, \
-    glib2fsn, xdg_get_user_dirs, get_home_dir
+    glib2fsn, xdg_get_user_dirs, get_home_dir, xdg_get_config_home
 from quodlibet.util import connect_obj
 
 
@@ -180,7 +180,7 @@ def get_gtk_bookmarks():
     if os.name == "nt":
         return []
 
-    path = os.path.join(get_home_dir(), ".gtk-bookmarks")
+    path = os.path.join(xdg_get_config_home(), "gtk-3.0", "bookmarks")
     folders = []
     try:
         with open(path, "rb") as f:
@@ -237,7 +237,7 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
             niter = model.append(None, [path])
             if path is not None:
                 assert isinstance(path, fsnative)
-                model.append(niter, ["dummy"])
+                model.append(niter, [fsnative(u"dummy")])
 
         self.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
         self.connect(
@@ -249,6 +249,18 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
         if initial:
             self.go_to(initial)
 
+        menu = self._create_menu()
+        connect_obj(self, 'popup-menu', self._popup_menu, menu)
+
+        # Allow to drag and drop files from outside
+        targets = [
+            ("text/uri-list", 0, 42)
+        ]
+        targets = [Gtk.TargetEntry.new(*t) for t in targets]
+        self.drag_dest_set(Gtk.DestDefaults.ALL, targets, Gdk.DragAction.COPY)
+        self.connect('drag-data-received', self.__drag_data_received)
+
+    def _create_menu(self):
         menu = Gtk.Menu()
         m = qltk.MenuItem(_(u"_New Folder…"), Icons.DOCUMENT_NEW)
         m.connect('activate', self.__mkdir)
@@ -263,15 +275,7 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
         m.connect('activate', self.__expand)
         menu.append(m)
         menu.show_all()
-        connect_obj(self, 'popup-menu', self.__popup_menu, menu)
-
-        # Allow to drag and drop files from outside
-        targets = [
-            ("text/uri-list", 0, 42)
-        ]
-        targets = [Gtk.TargetEntry.new(*t) for t in targets]
-        self.drag_dest_set(Gtk.DestDefaults.ALL, targets, Gdk.DragAction.COPY)
-        self.connect('drag-data-received', self.__drag_data_received)
+        return menu
 
     def get_selected_paths(self):
         """A list of fs paths"""
@@ -283,7 +287,11 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
     def go_to(self, path_to_go):
         assert isinstance(path_to_go, fsnative)
 
-        # FIXME: what about non-normalized paths?
+        # The path should be normalized in normal situations.
+        # On some systems and special environments (pipenv) there might be
+        # a non-normalized path at least during tests, though.
+        path_to_go = os.path.normpath(path_to_go)
+
         model = self.get_model()
 
         # Find the top level row which has the largest common
@@ -342,24 +350,26 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
                     return
         Gtk.drag_finish(drag_ctx, False, False, time)
 
-    def __popup_menu(self, menu):
+    def _popup_menu(self, menu):
         model, paths = self.get_selection().get_selected_rows()
-        if len(paths) != 1:
-            return True
 
-        path = paths[0]
-        directory = model[path][0]
-        delete = menu.get_children()[1]
+        directories = [model[path][0] for path in paths]
+        menu_items = menu.get_children()
+        delete = menu_items[1]
         try:
-            delete.set_sensitive(len(os.listdir(directory)) == 0)
+            is_empty = not any(len(os.listdir(d)) for d in directories)
+            delete.set_sensitive(is_empty)
         except OSError as err:
             if err.errno == errno.ENOENT:
-                model.remove(model.get_iter(path))
+                model.remove(model.get_iter(paths[0]))
             return False
+        new_folder = menu_items[0]
+        new_folder.set_sensitive(len(paths) == 1)
 
         selection = self.get_selection()
         selection.unselect_all()
-        selection.select_path(path)
+        for path in paths:
+            selection.select_path(path)
         return self.popup_menu(menu, 0, Gtk.get_current_event_time())
 
     def __mkdir(self, button):
@@ -392,17 +402,17 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
 
     def __rmdir(self, button):
         model, paths = self.get_selection().get_selected_rows()
-        if len(paths) != 1:
-            return
 
-        directory = model[paths[0]][0]
-        try:
-            os.rmdir(directory)
-        except EnvironmentError as err:
-            error = "<b>%s</b>: %s" % (err.filename, err.strerror)
-            qltk.ErrorMessage(
-                None, _("Unable to delete folder"), error).run()
-            return
+        directories = [model[path][0] for path in paths]
+        print_d("Deleting %d empty directories" % len(directories))
+        for directory in directories:
+            try:
+                os.rmdir(directory)
+            except EnvironmentError as err:
+                error = "<b>%s</b>: %s" % (err.filename, err.strerror)
+                qltk.ErrorMessage(
+                    None, _("Unable to delete folder"), error).run()
+                return
 
         ppath = Gtk.TreePath(paths[0][:-1])
         expanded = self.row_expanded(ppath)
@@ -424,7 +434,7 @@ class DirectoryTree(RCMHintedTreeView, MultiDragTreeView):
         nchildren = model.iter_n_children(iter_)
         last = model.get_path(iter_)
 
-        for i in xrange(nchildren):
+        for i in range(nchildren):
             child = model.iter_nth_child(iter_, i)
             self.expand_row(model.get_path(child), False)
             last = self.__select_children(child, model, selection)
@@ -515,6 +525,7 @@ class FileSelector(Paned):
 
         model = ObjectStore()
         filelist = AllTreeView(model=model)
+        filelist.connect("draw", self.__restore_scroll_pos_on_draw)
 
         column = TreeViewColumn(title=_("Songs"))
         column.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
@@ -627,6 +638,13 @@ class FileSelector(Paned):
 
         fselect.handler_unblock(self.__sig)
         fselect.emit('changed')
+        self._saved_scroll_pos = filelist.get_vadjustment().get_value()
+
+    def __restore_scroll_pos_on_draw(self, treeview, context):
+        if self._saved_scroll_pos:
+            vadj = treeview.get_vadjustment()
+            vadj.set_value(self._saved_scroll_pos)
+            self._saved_scroll_pos = None
 
 
 def _get_main_folders():
