@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2009 Joe Wreschnig, Michael Urman, Iñigo Serna,
 #                     Steven Robertson
-#           2011-2016 Nick Boultbee
+#           2011-2017 Nick Boultbee
 #           2013      Christoph Reiter
 #           2014      Jan Path
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -324,7 +325,8 @@ class PreferencesWindow(UniqueWindow):
 
             entry = UndoEntry()
             entry.set_tooltip_text(
-                    _("The album art image file to use when forced"))
+                    _("The album art image file to use when forced"
+                      " (supports wildcards)"))
             entry.set_text(config.get("albumart", "filename"))
             entry.connect('changed', self.__changed_text, 'filename')
             # Disable entry when not forcing
@@ -378,7 +380,7 @@ class PreferencesWindow(UniqueWindow):
             fb_label.set_mnemonic_widget(fb_spin)
 
             pre_amp_gain = config.getfloat("player", "pre_amp_gain", 0.0)
-            adj = Gtk.Adjustment.new(pre_amp_gain, -6, 6, 0.5, 0.5, 0.0)
+            adj = Gtk.Adjustment.new(pre_amp_gain, -12, 12, 0.5, 0.5, 0.0)
             adj.connect('value-changed', self.__changed,
                         'player', 'pre_amp_gain')
             pre_spin = Gtk.SpinButton(adjustment=adj)
@@ -553,16 +555,25 @@ class PreferencesWindow(UniqueWindow):
             hb.pack_start(bayes_label, False, True, 0)
             hb.pack_start(bayes_spin, False, True, 0)
             vb.pack_start(hb, True, True, 0)
-            cb = CCB(_("Save ratings and play _counts"),
+            cb = CCB(_("Save ratings and play _counts in tags"),
                      "editing", "save_to_songs", populate=True)
+
+            def update_entry(widget, email_entry):
+                email_entry.set_sensitive(widget.get_active())
+
             vb.pack_start(cb, True, True, 0)
             hb = Gtk.HBox(spacing=6)
             lab = Gtk.Label(label=_("_Email:"))
             entry = UndoEntry()
-            entry.set_tooltip_text(_("Ratings and play counts will be set "
-                                     "for this email address"))
+            entry.set_tooltip_text(_("Ratings and play counts will be saved "
+                                     "in tags for this email address"))
             entry.set_text(config.get("editing", "save_email"))
             entry.connect('changed', self.__changed, 'editing', 'save_email')
+
+            # Disable the entry if not saving to tags
+            cb.connect('clicked', update_entry, entry)
+            update_entry(cb, entry)
+
             hb.pack_start(lab, False, True, 0)
             hb.pack_start(entry, True, True, 0)
             lab.set_mnemonic_widget(entry)
@@ -626,7 +637,7 @@ class PreferencesWindow(UniqueWindow):
             config.set(section, name, str(entry.get_value()))
             print_d("Signalling \"changed\" to entire library. Hold tight...")
             # Cache over clicks
-            self._songs = self._songs or app.library.values()
+            self._songs = self._songs or list(app.library.values())
             copool.add(emit_signal, self._songs, funcid="library changed",
                        name=_("Updating for new ratings"))
 
