@@ -2,30 +2,38 @@
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import unicodedata
+import glob
+import shutil
 
 from gi.repository import Gtk, Gdk
+from senf import fsn2text, text2fsn
 
 import quodlibet
 from quodlibet import qltk
 from quodlibet import util
+from quodlibet import config
+from quodlibet import _
 
 from quodlibet.plugins import PluginManager
 from quodlibet.pattern import FileFromPattern
+from quodlibet.pattern import ArbitraryExtensionFileFromPattern
 from quodlibet.qltk._editutils import FilterPluginBox, FilterCheckButton
 from quodlibet.qltk._editutils import EditingPluginHandler
 from quodlibet.qltk.views import TreeViewColumn
 from quodlibet.qltk.cbes import ComboBoxEntrySave
+from quodlibet.qltk.ccb import ConfigCheckButton
 from quodlibet.qltk.models import ObjectStore
-from quodlibet.qltk import Icons, Button
+from quodlibet.qltk import Icons, Button, Frame
 from quodlibet.qltk.wlw import WritingWindow
 from quodlibet.util import connect_obj
-from quodlibet.util.path import fsdecode, fsnative
 from quodlibet.util.path import strip_win32_incompat_from_path
+from quodlibet.util.dprint import print_d
 
 
 NBP = os.path.join(quodlibet.get_user_dir(), "lists", "renamepatterns")
@@ -35,7 +43,9 @@ NBP_EXAMPLES = """\
 <tracknumber> - <title>
 <tracknumber> - <artist> - <title>
 /path/<artist> - <album>/<tracknumber>. <title>
-/path/<artist>/<album>/<tracknumber> - <title>"""
+~/<artist>/<album>/<tracknumber> - <title>
+<albumartist|<albumartist>|<artist>>/(<~year>) <album>\
+/<tracknumber|<tracknumber> - ><title>"""
 
 
 class SpacesToUnderscores(FilterCheckButton):
@@ -73,8 +83,7 @@ class StripDiacriticals(FilterCheckButton):
     _order = 1.2
 
     def filter(self, original, filename):
-        filename = fsdecode(filename)
-        return fsnative(filter(lambda s: not unicodedata.combining(s),
+        return u"".join(filter(lambda s: not unicodedata.combining(s),
                                unicodedata.normalize('NFKD', filename)))
 
 
@@ -85,9 +94,7 @@ class StripNonASCII(FilterCheckButton):
     _order = 1.3
 
     def filter(self, original, filename):
-        filename = fsdecode(filename)
-        return fsnative(
-            u"".join(map(lambda s: (s <= "~" and s) or u"_", filename)))
+        return u"".join(map(lambda s: (s <= "~" and s) or u"_", filename))
 
 
 class Lowercase(FilterCheckButton):
@@ -115,7 +122,7 @@ class Entry(object):
 
     @property
     def name(self):
-        return fsdecode(self.song("~basename"))
+        return fsn2text(self.song("~basename"))
 
 
 class RenameFiles(Gtk.VBox):
@@ -123,6 +130,7 @@ class RenameFiles(Gtk.VBox):
     FILTERS = [SpacesToUnderscores, StripWindowsIncompat, StripDiacriticals,
                StripNonASCII, Lowercase]
     handler = RenameFilesPluginHandler()
+    IMAGE_EXTENSIONS = ['jpg', 'jpeg', 'png', 'bmp']
 
     @classmethod
     def init_plugins(cls):
@@ -130,6 +138,7 @@ class RenameFiles(Gtk.VBox):
 
     def __init__(self, parent, library):
         super(RenameFiles, self).__init__(spacing=6)
+        self.__skip_interactive = False
         self.set_border_width(12)
 
         hbox = Gtk.HBox(spacing=6)
@@ -157,11 +166,52 @@ class RenameFiles(Gtk.VBox):
 
         self.pack_start(Gtk.VBox(), False, True, 0)
 
+        # rename options
+        rename_options = Gtk.HBox()
+
+        # file name options
         filter_box = FilterPluginBox(self.handler, self.FILTERS)
         filter_box.connect("preview", self.__filter_preview)
         filter_box.connect("changed", self.__filter_changed)
         self.filter_box = filter_box
-        self.pack_start(filter_box, False, True, 0)
+
+        frame_filename_options = Frame(_("File names"), filter_box)
+        frame_filename_options.show_all()
+        rename_options.pack_start(frame_filename_options, False, True, 0)
+
+        # album art options
+        albumart_box = Gtk.VBox()
+
+        # move art
+        moveart_box = Gtk.VBox()
+        self.moveart = ConfigCheckButton(
+             _('_Move album art'),
+             "rename", "move_art", populate=True)
+        self.moveart.set_tooltip_text(
+             _("See '[albumart] filenames' config entry " +
+               "for image search strings"))
+        self.moveart.show()
+        moveart_box.pack_start(self.moveart, False, True, 0)
+        self.moveart_overwrite = ConfigCheckButton(
+             _('_Overwrite album art at target'),
+             "rename", "move_art_overwrite", populate=True)
+        self.moveart_overwrite.show()
+        moveart_box.pack_start(self.moveart_overwrite, False, True, 0)
+        albumart_box.pack_start(moveart_box, False, True, 0)
+        # remove empty
+        removeemptydirs_box = Gtk.VBox()
+        self.removeemptydirs = ConfigCheckButton(
+             _('_Remove empty directories'),
+             "rename", "remove_empty_dirs", populate=True)
+        self.removeemptydirs.show()
+        removeemptydirs_box.pack_start(self.removeemptydirs, False, True, 0)
+        albumart_box.pack_start(removeemptydirs_box, False, True, 0)
+
+        frame_albumart_options = Frame(_("Album art"), albumart_box)
+        frame_albumart_options.show_all()
+        rename_options.pack_start(frame_albumart_options, False, True, 0)
+
+        self.pack_start(rename_options, False, True, 0)
 
         # Save button
         self.save = Button(_("_Save"), Icons.DOCUMENT_SAVE)
@@ -172,7 +222,8 @@ class RenameFiles(Gtk.VBox):
         self.pack_start(bbox, False, True, 0)
 
         render = Gtk.CellRendererText()
-        column = TreeViewColumn(_('File'), render)
+        column = TreeViewColumn(title=_('File'))
+        column.pack_start(render, True)
 
         def cell_data_file(column, cell, model, iter_, data):
             entry = model.get_value(iter_)
@@ -185,7 +236,8 @@ class RenameFiles(Gtk.VBox):
 
         render = Gtk.CellRendererText()
         render.set_property('editable', True)
-        column = TreeViewColumn(_('New Name'), render)
+        column = TreeViewColumn(title=_('New Name'))
+        column.pack_start(render, True)
 
         def cell_data_new_name(column, cell, model, iter_, data):
             entry = model.get_value(iter_)
@@ -195,10 +247,10 @@ class RenameFiles(Gtk.VBox):
         column.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
         self.view.append_column(column)
 
-        connect_obj(self.preview, 'clicked', self.__preview, None)
+        connect_obj(self.preview, 'clicked', self._preview, None)
 
-        connect_obj(parent, 'changed', self.__class__.__preview, self)
-        connect_obj(self.save, 'clicked', self.__rename, library)
+        connect_obj(parent, 'changed', self.__class__._preview, self)
+        connect_obj(self.save, 'clicked', self._rename, library)
 
         render.connect('edited', self.__row_edited)
 
@@ -219,30 +271,42 @@ class RenameFiles(Gtk.VBox):
         path = Gtk.TreePath.new_from_string(path)
         model = self.view.get_model()
         entry = model[path][0]
-        new = new.decode("utf-8")
         if entry.new_name != new:
             entry.new_name = new
             self.preview.set_sensitive(True)
             self.save.set_sensitive(True)
             model.path_changed(path)
 
-    def __rename(self, library):
+    def _rename(self, library):
         model = self.view.get_model()
         win = WritingWindow(self, len(model))
         win.show()
         was_changed = set()
-        skip_all = False
+        skip_all = self.__skip_interactive
         self.view.freeze_child_notify()
+        should_move_art = config.getboolean("rename", "move_art")
+        moveart_sets = {}
+        remove_empty_dirs = config.getboolean("rename", "remove_empty_dirs")
 
-        for entry in model.itervalues():
-            song = entry.song
-            new_name = entry.new_name
-            old_name = entry.name
-            if new_name is None:
+        for entry in model.values():
+            if entry.new_name is None:
                 continue
+            song = entry.song
+            old_name = entry.name
+            old_pathfile = song['~filename']
+            new_name = entry.new_name
+            new_pathfile = ""
+            # ensure target is a full path
+            if os.path.abspath(new_name) != \
+                   os.path.abspath(os.path.join(os.getcwd(), new_name)):
+                new_pathfile = new_name
+            else:
+                # must be a relative pattern, so prefix the path
+                new_pathfile = \
+                    os.path.join(os.path.dirname(old_pathfile), new_name)
 
             try:
-                library.rename(song, fsnative(new_name), changed=was_changed)
+                library.rename(song, text2fsn(new_name), changed=was_changed)
             except Exception:
                 util.print_exc()
                 if skip_all:
@@ -271,6 +335,19 @@ class RenameFiles(Gtk.VBox):
                 library.reload(song, changed=was_changed)
                 if resp != Gtk.ResponseType.OK and resp != RESPONSE_SKIP_ALL:
                     break
+
+            if should_move_art:
+                self._moveart(moveart_sets, old_pathfile, new_pathfile, song)
+
+            if remove_empty_dirs:
+                path_old = os.path.dirname(old_pathfile)
+                if not os.listdir(path_old):
+                    try:
+                        os.rmdir(path_old)
+                        print_d("Removed empty directory: %r" % path_old, self)
+                    except Exception:
+                        util.print_exc()
+
             if win.step():
                 break
 
@@ -279,12 +356,83 @@ class RenameFiles(Gtk.VBox):
         library.changed(was_changed)
         self.save.set_sensitive(False)
 
-    def __preview(self, songs):
+    def _moveart(self, art_sets, pathfile_old, pathfile_new, song):
+
+        path_old = os.path.dirname(os.path.realpath(pathfile_old))
+        path_new = os.path.dirname(os.path.realpath(pathfile_new))
+        if os.path.realpath(path_old) == os.path.realpath(path_new):
+            return
+        if (path_old in art_sets.keys() and not art_sets[path_old]):
+            return
+
+        # get art set for path
+        images = []
+        if path_old in art_sets.keys():
+            images = art_sets[path_old]
+        else:
+            def glob_escape(s):
+                for c in '[*?':
+                    s = s.replace(c, '[' + c + ']')
+                return s
+
+            # generate art set for path
+            art_sets[path_old] = images
+            path_old_escaped = glob_escape(path_old)
+            for suffix in self.IMAGE_EXTENSIONS:
+                images.extend(glob.glob(os.path.join(path_old_escaped,
+                                                     "*." + suffix)))
+        if images:
+            # set not empty yet, (re)process
+            filenames = config.getstringlist("albumart", "search_filenames")
+            moves = []
+            for fn in filenames:
+                fn = os.path.join(path_old, fn)
+                if "<" in fn:
+                    # resolve path
+                    fnres = ArbitraryExtensionFileFromPattern(fn).format(song)
+                    if fnres in images and fnres not in moves:
+                        moves.append(fnres)
+                elif "*" in fn:
+                    moves.extend(f for f in glob.glob(fn)
+                                     if f in images and f not in moves)
+                elif fn in images and fn not in moves:
+                    moves.append(fn)
+            if len(moves) > 0:
+                overwrite = config.getboolean("rename", "move_art_overwrite")
+                for fnmove in moves:
+                    try:
+                        # existing files safeguarded until move successful,
+                        # then deleted if overwrite set
+                        fnmoveto = os.path.join(path_new,
+                                                os.path.split(fnmove)[1])
+                        fnmoveto_orig = ""
+                        if os.path.exists(fnmoveto):
+                            fnmoveto_orig = fnmoveto + ".orig"
+                            if not os.path.exists(fnmoveto_orig):
+                                os.rename(fnmoveto, fnmoveto_orig)
+                            else:
+                                suffix = 1
+                                while os.path.exists(fnmoveto_orig +
+                                                     "." + str(suffix)):
+                                    suffix += 1
+                                fnmoveto_orig = (fnmoveto_orig +
+                                                 "." + str(suffix))
+                                os.rename(fnmoveto, fnmoveto_orig)
+                        print_d("Renaming image %r to %r" %
+                                   (fnmove, fnmoveto), self)
+                        shutil.move(fnmove, fnmoveto)
+                        if overwrite and fnmoveto_orig:
+                            os.remove(fnmoveto_orig)
+                        images.remove(fnmove)
+                    except Exception:
+                        util.print_exc()
+
+    def _preview(self, songs):
         model = self.view.get_model()
         if songs is None:
-            songs = [e.song for e in model.itervalues()]
+            songs = [e.song for e in model.values()]
 
-        pattern_text = self.combo.get_child().get_text().decode("utf-8")
+        pattern_text = self.combo.get_child().get_text()
 
         try:
             pattern = FileFromPattern(pattern_text)
@@ -295,7 +443,7 @@ class RenameFiles(Gtk.VBox):
                   "does not start from root. To avoid misnamed "
                   "folders, root your pattern by starting "
                   "it with / or ~/.") % (
-                util.escape(pattern))).run()
+                util.escape(pattern_text))).run()
             return
         else:
             if pattern:
@@ -304,7 +452,7 @@ class RenameFiles(Gtk.VBox):
 
         # native paths
         orignames = [song["~filename"] for song in songs]
-        newnames = [pattern.format(song) for song in songs]
+        newnames = [fsn2text(pattern.format(song)) for song in songs]
         for f in self.filter_box.filters:
             if f.active:
                 newnames = f.filter_list(orignames, newnames)
@@ -312,7 +460,7 @@ class RenameFiles(Gtk.VBox):
         model.clear()
         for song, newname in zip(songs, newnames):
             entry = Entry(song)
-            entry.new_name = fsdecode(newname)
+            entry.new_name = newname
             model.append(row=[entry])
 
         self.preview.set_sensitive(False)
@@ -323,3 +471,11 @@ class RenameFiles(Gtk.VBox):
                 break
         else:
             self.set_sensitive(True)
+
+    @property
+    def test_mode(self):
+        return self.__skip_interactive
+
+    @test_mode.setter
+    def test_mode(self, value):
+        self.__skip_interactive = value
