@@ -3,15 +3,17 @@
 #           2012, 2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
-import os
 import contextlib
 
 from gi.repository import Gtk, Gdk, GObject, Pango, GLib
 import cairo
+from senf import environ
 
+from quodlibet import _, print_e
 from quodlibet import config
 from quodlibet.qltk import get_top_parent, is_accel, is_wayland, gtk_version, \
     menu_popup, get_primary_accel_mod
@@ -158,7 +160,7 @@ class TreeViewHints(Gtk.Window):
         # For gtk3.16 overlay scrollbars: if our event x coordinate
         # is contained in the scrollbar, hide the tooltip. Unlike other
         # hiding events we don't want to send a leave event to the scrolled
-        # window so the overlay scrollbar does't hide and can be interacted
+        # window so the overlay scrollbar doesn't hide and can be interacted
         # with.
         parent = view.get_parent()
         # We only need to check if the tooltip is there since events
@@ -173,8 +175,10 @@ class TreeViewHints(Gtk.Window):
                     self.__undisplay(send_leave=False)
                     return False
 
-        # hide if any modifier is active
-        if event.get_state() & Gtk.accelerator_get_default_mod_mask():
+        # hide if any modifier is active.
+        mask = Gtk.accelerator_get_default_mod_mask()
+        mask = Gdk.Keymap.get_default().map_virtual_modifiers(mask)[1]
+        if event.get_state() & mask:
             self.__undisplay()
             return False
 
@@ -200,7 +204,7 @@ class TreeViewHints(Gtk.Window):
         # get the renderer at the mouse position and get the xpos/width
         renderers = col.get_cells()
         pos = sorted(zip(map(col.cell_get_position, renderers), renderers))
-        pos = filter(lambda p: p[0][0] < cellx, pos)
+        pos = list(filter(lambda p: p[0][0] < cellx, pos))
         if not pos:
             self.__undisplay()
             return False
@@ -656,7 +660,13 @@ class BaseView(Gtk.TreeView):
 
         self.connect("button-release-event", on_button_release_event)
 
+    def do_key_press_event(self, event):
+        if is_accel(event, "space", "KP_Space"):
+            return False
+        return Gtk.TreeView.do_key_press_event(self, event)
+
     def __key_pressed(self, view, event):
+
         def get_first_selected():
             selection = self.get_selection()
             model, paths = selection.get_selected_rows()
@@ -682,7 +692,8 @@ class BaseView(Gtk.TreeView):
     def remove_paths(self, paths):
         """Remove rows and restore the selection if it got removed"""
 
-        self.remove_iters(map(self.get_model().get_iter, paths))
+        model = self.get_model()
+        self.remove_iters([model.get_iter(p) for p in paths])
 
     def remove_iters(self, iters):
         """Remove rows and restore the selection if it got removed"""
@@ -701,7 +712,7 @@ class BaseView(Gtk.TreeView):
                 self.__remove_iters([iter_], force_restore=True)
         elif mode == Gtk.SelectionMode.MULTIPLE:
             model, paths = selection.get_selected_rows()
-            iters = map(model.get_iter, paths or [])
+            iters = list(map(model.get_iter, paths or []))
             self.__remove_iters(iters, force_restore=True)
 
     def select_by_func(self, func, scroll=True, one=False):
@@ -954,18 +965,20 @@ class DragIconTreeView(BaseView):
 
 
 class MultiDragTreeView(BaseView):
-    """TreeView with multirow drag support:
+    """TreeView with multirow drag support.
 
-    - Selections don't change until button-release-event...
-    - Unless they're a Shift/Ctrl modification, then they happen immediately
-    - Drag icons include 3 rows/2 plus a "and more" count
+    Button press events which would result in a row getting unselected
+    get delayed until the next button release event.
+
+    This makes it possible to drag one or more selected rows without
+    changing the selection.
     """
 
     def __init__(self, *args, **kwargs):
         super(MultiDragTreeView, self).__init__(*args, **kwargs)
         self.connect('button-press-event', self.__button_press)
         self.connect('button-release-event', self.__button_release)
-        self.__pending_event = None
+        self.__pending_action = None
 
     def __button_press(self, view, event):
         if event.button == Gdk.BUTTON_PRIMARY:
@@ -977,35 +990,28 @@ class MultiDragTreeView(BaseView):
             path, col, cellx, celly = self.get_path_at_pos(x, y)
         except TypeError:
             return True
-        self.grab_focus()
         selection = self.get_selection()
         is_selected = selection.path_is_selected(path)
         mod_active = event.get_state() & (
             get_primary_accel_mod() | Gdk.ModifierType.SHIFT_MASK)
 
-        if is_selected and not mod_active:
-            self.__pending_event = [x, y]
+        if is_selected:
+            self.__pending_action = (path, col, mod_active)
             selection.set_select_function(lambda *args: False, None)
-        elif event.type == Gdk.EventType.BUTTON_PRESS:
-            self.__pending_event = None
+        else:
+            self.__pending_action = None
             selection.set_select_function(lambda *args: True, None)
 
     def __button_release(self, view, event):
-        if self.__pending_event:
+        if self.__pending_action:
+            path, col, single_unselect = self.__pending_action
             selection = self.get_selection()
             selection.set_select_function(lambda *args: True, None)
-            oldevent = self.__pending_event
-            self.__pending_event = None
-
-            x, y = map(int, [event.x, event.y])
-            if oldevent != [x, y]:
-                return True
-
-            try:
-                path, col, cellx, celly = self.get_path_at_pos(x, y)
-            except TypeError:
-                return True
-            self.set_cursor(path, col, 0)
+            if single_unselect:
+                selection.unselect_path(path)
+            else:
+                self.set_cursor(path, col, 0)
+            self.__pending_action = None
 
 
 class RCMTreeView(BaseView):
@@ -1127,12 +1133,17 @@ class HintedTreeView(BaseView):
                 tvh = HintedTreeView.hints = TreeViewHints()
             tvh.connect_view(self)
 
+    def set_tooltip_text(self, *args, **kwargs):
+        print_e("Setting a tooltip on the view breaks tv hints. Set it"
+                " on the parent scrolled window instead")
+        return super(HintedTreeView, self).set_tooltip_text(*args, **kwargs)
+
     def supports_hints(self):
         """If the treeview hints support is enabled. Can be used to
         display scroll bars instead for example.
         """
 
-        if "QUODLIBET_NO_HINTS" in os.environ:
+        if "QUODLIBET_NO_HINTS" in environ:
             return False
 
         return not config.state('disable_hints')
