@@ -2,11 +2,12 @@
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman
 #           2011 Christoph Reiter
 #           2016 Ryan Dellenbaugh
-#           2016 Nick Boultbee
+#        2016-17 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import time
 import operator
@@ -14,7 +15,6 @@ import operator
 from senf import fsn2text, fsnative
 
 from quodlibet.unisearch import compile
-from quodlibet.compat import floordiv, text_type
 from quodlibet.util import parse_date
 from quodlibet.formats import FILESYSTEM_TAGS, TIME_TAGS
 
@@ -51,8 +51,8 @@ class Node(object):
 class Regex(Node):
 
     def __init__(self, pattern, mod_string):
-        self.pattern = text_type(pattern)
-        self.mod_string = text_type(mod_string)
+        self.pattern = str(pattern)
+        self.mod_string = str(mod_string)
 
         ignore_case = "c" not in self.mod_string or "i" in self.mod_string
         dot_all = "s" in self.mod_string
@@ -87,6 +87,26 @@ class True_(Node):
         return other
 
 
+class False_(Node):
+    """Always False"""
+
+    def search(self, data):
+        return False
+
+    def filter(self, list_):
+        return []
+
+    def __repr__(self):
+        return "<False>"
+
+    def __or__(self, other):
+        other = other._unpack()
+        return other
+
+    def __and__(self, other):
+        return self
+
+
 class Union(Node):
     """True if the object matches any of its REs."""
 
@@ -269,7 +289,10 @@ class NumexprTag(Numexpr):
         else:
             num = data(self._ftag, None)
         if num is not None:
-            if self._ftag in TIME_TAGS:
+            # Strip aggregate function from tag
+            func_start = self._ftag.find(":")
+            tag = self._ftag[:func_start] if func_start >= 0 else self._ftag
+            if tag in TIME_TAGS:
                 num = time - num
             return round(num, 2)
         return None
@@ -312,14 +335,14 @@ class NumexprBinary(Numexpr):
         '-': operator.sub,
         '+': operator.add,
         '*': operator.mul,
-        '/': floordiv,
+        '/': operator.floordiv,
     }
 
     precedence = {
         operator.sub: 1,
         operator.add: 1,
         operator.mul: 2,
-        floordiv: 2,
+        operator.floordiv: 2,
     }
 
     def __init__(self, op, expr, expr2):
