@@ -2,11 +2,14 @@
 # Copyright 2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 
+from senf import path2fsn, fsn2bytes, bytes2fsn, fsnative
+
 from quodlibet.util import fifo, print_w
 from quodlibet import get_user_dir
 try:
@@ -23,39 +26,53 @@ class RemoteBase(object):
     """A thing for communicating with existing instances of ourself."""
 
     def __init__(self, app, cmd_registry):
-        """Takes an Application and CommandRegistry"""
+        """
+        Args:
+            app (Application)
+            cmd_registry (CommandRegistry)
+        """
 
-        raise NotImplemented
+        raise NotImplementedError
 
     @classmethod
     def remote_exists(self):
-        """See if another instance exists"""
+        """See if another instance exists
 
-        raise NotImplemented
+        Returns:
+            bool
+        """
+
+        raise NotImplementedError
 
     @classmethod
     def send_message(cls, message):
         """Send data to the existing instance if possible and returns
         a response.
 
-        Raises RemoteError in case the message couldn't be send or
-        there was no response.
+        Args:
+            message (fsnative)
+        Returns:
+            fsnative or None
+        Raises:
+            RemoteError: in case the message couldn't be send or
+                there was no response.
         """
 
-        raise NotImplemented
+        raise NotImplementedError
 
     def start(self):
         """Start the listener for other instances.
 
-        Might raise RemoteError in case another instance is already listening.
+        Raises:
+            RemoteError: in case another instance is already listening.
         """
 
-        raise NotImplemented
+        raise NotImplementedError
 
     def stop(self):
         """Stop the listener for other instances"""
 
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class QuodLibetWinRemote(RemoteBase):
@@ -73,8 +90,9 @@ class QuodLibetWinRemote(RemoteBase):
 
     @classmethod
     def send_message(cls, message):
+        data = fsn2bytes(path2fsn(message), "utf-8")
         try:
-            winpipe.write_pipe(cls._NAME, message)
+            winpipe.write_pipe(cls._NAME, data)
         except EnvironmentError as e:
             raise RemoteError(e)
 
@@ -88,7 +106,8 @@ class QuodLibetWinRemote(RemoteBase):
         self._server.stop()
 
     def _callback(self, data):
-        self._cmd_registry.handle_line(self._app, data)
+        message = bytes2fsn(data, "utf-8")
+        self._cmd_registry.handle_line(self._app, message)
 
 
 class QuodLibetUnixRemote(RemoteBase):
@@ -107,8 +126,10 @@ class QuodLibetUnixRemote(RemoteBase):
 
     @classmethod
     def send_message(cls, message):
+        assert isinstance(message, fsnative)
+
         try:
-            return fifo.write_fifo(cls._PATH, message)
+            return fifo.write_fifo(cls._PATH, fsn2bytes(message, None))
         except EnvironmentError as e:
             raise RemoteError(e)
 
@@ -127,12 +148,16 @@ class QuodLibetUnixRemote(RemoteBase):
         except ValueError:
             print_w("invalid message: %r" % data)
             return
+
         for command, path in messages:
+            command = bytes2fsn(command, None)
             response = self._cmd_registry.handle_line(self._app, command)
             if path is not None:
+                path = bytes2fsn(path, None)
                 with open(path, "wb") as h:
                     if response is not None:
-                        h.write(response)
+                        assert isinstance(response, fsnative)
+                        h.write(fsn2bytes(response, None))
 
 
 if os.name == "nt":
