@@ -2,8 +2,9 @@
 # Copyright 2006 Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import sys
@@ -12,20 +13,8 @@ import locale
 
 from senf import environ, path2fsn, fsn2text, text2fsn
 
-from quodlibet.util.path import unexpand
+from quodlibet.util.path import unexpand, xdg_get_system_data_dirs
 from quodlibet.util.dprint import print_d
-from quodlibet.compat import text_type, PY2, listfilter
-
-from .misc import get_locale_encoding
-
-
-def locale_format(format, val, *args, **kwargs):
-    """Like locale.format but returns text"""
-
-    result = locale.format(format, val, *args, **kwargs)
-    if isinstance(result, bytes):
-        result = result.decode(get_locale_encoding(), "replace")
-    return result
 
 
 def bcp47_to_language(code):
@@ -80,9 +69,9 @@ def set_i18n_envvars():
         from quodlibet.util.winapi import GetUserDefaultUILanguage, \
             GetSystemDefaultUILanguage
 
-        langs = listfilter(None, map(locale.windows_locale.get,
-                                     [GetUserDefaultUILanguage(),
-                                      GetSystemDefaultUILanguage()]))
+        langs = list(filter(None, map(locale.windows_locale.get,
+                                      [GetUserDefaultUILanguage(),
+                                       GetSystemDefaultUILanguage()])))
         if langs:
             environ.setdefault('LANG', langs[0])
             environ.setdefault('LANGUAGE', ":".join(langs))
@@ -150,27 +139,20 @@ class GlibTranslations(gettext.GNUTranslations):
         # force unicode here since __contains__ (used in gettext) ignores
         # our changed defaultencoding for coercion, so utf-8 encoded strings
         # fail at lookup.
-        message = text_type(message)
-        if PY2:
-            return text_type(gettext.GNUTranslations.ugettext(self, message))
-        else:
-            return text_type(gettext.GNUTranslations.gettext(self, message))
+        message = str(message)
+        return str(gettext.GNUTranslations.gettext(self, message))
 
     def ungettext(self, msgid1, msgid2, n):
         # see ugettext
-        msgid1 = text_type(msgid1)
-        msgid2 = text_type(msgid2)
-        if PY2:
-            return text_type(
-                gettext.GNUTranslations.ungettext(self, msgid1, msgid2, n))
-        else:
-            return text_type(
-                gettext.GNUTranslations.ngettext(self, msgid1, msgid2, n))
+        msgid1 = str(msgid1)
+        msgid2 = str(msgid2)
+        return str(
+            gettext.GNUTranslations.ngettext(self, msgid1, msgid2, n))
 
     def unpgettext(self, context, msgid, msgidplural, n):
-        context = text_type(context)
-        msgid = text_type(msgid)
-        msgidplural = text_type(msgidplural)
+        context = str(context)
+        msgid = str(msgid)
+        msgidplural = str(msgidplural)
         real_msgid = u"%s\x04%s" % (context, msgid)
         real_msgidplural = u"%s\x04%s" % (context, msgidplural)
         result = self.ngettext(real_msgid, real_msgidplural, n)
@@ -181,8 +163,8 @@ class GlibTranslations(gettext.GNUTranslations):
         return result
 
     def upgettext(self, context, msgid):
-        context = text_type(context)
-        msgid = text_type(msgid)
+        context = str(context)
+        msgid = str(msgid)
         real_msgid = u"%s\x04%s" % (context, msgid)
         result = self.ugettext(real_msgid)
         if result == real_msgid:
@@ -212,7 +194,7 @@ _translations = {
 def set_debug_text(debug_text=None):
     """
     Args:
-        debug_text (text_type or None): text to add to all translations
+        debug_text (str or None): text to add to all translations
     """
 
     global _debug_text, _translations
@@ -222,13 +204,28 @@ def set_debug_text(debug_text=None):
         trans.set_debug_text(debug_text)
 
 
+def iter_locale_dirs():
+    dirs = list(xdg_get_system_data_dirs())
+    # this is the one python gettext uses by default, use as a fallback
+    dirs.append(os.path.join(sys.base_prefix, "share"))
+
+    done = set()
+    for path in dirs:
+        locale_dir = os.path.join(path, "locale")
+        if locale_dir in done:
+            continue
+        done.add(locale_dir)
+        if os.path.isdir(locale_dir):
+            yield locale_dir
+
+
 def register_translation(domain, localedir=None):
     """Register a translation domain
 
     Args:
         domain (str): the gettext domain
-        localedir (pathlike): A directory used for translations, if it doesn't
-            exist the system one will be used.
+        localedir (pathlike): A directory used for translations, if None the
+            system one will be used.
     Returns:
         GlibTranslations
     """
@@ -237,19 +234,22 @@ def register_translation(domain, localedir=None):
 
     assert _initialized
 
-    if localedir is not None and os.path.isdir(localedir):
-        print_d("Using local localedir: %r" % unexpand(localedir))
-        gettext.bindtextdomain(domain, localedir)
-
-    localedir = gettext.bindtextdomain(domain)
-
-    try:
-        t = gettext.translation(domain, localedir, class_=GlibTranslations)
-    except IOError:
-        print_d("No translation found in %r" % unexpand(localedir))
-        t = GlibTranslations()
+    if localedir is None:
+        iterdirs = iter_locale_dirs
     else:
-        print_d("Translations loaded: %r" % unexpand(t.path))
+        iterdirs = lambda: iter([localedir])
+
+    for dir_ in iterdirs():
+        try:
+            t = gettext.translation(domain, dir_, class_=GlibTranslations)
+        except OSError:
+            continue
+        else:
+            print_d("Translations loaded: %r" % unexpand(t.path))
+            break
+    else:
+        print_d("No translation found for the domain %r" % domain)
+        t = GlibTranslations()
 
     t.set_debug_text(_debug_text)
     _translations[domain] = t
@@ -261,7 +261,7 @@ def init(language=None):
     and before any gettext using libraries are loaded.
 
     Args:
-        language (text_type or None): Either a language to use or None for the
+        language (str or None): Either a language to use or None for the
             system derived default.
     """
 
@@ -291,38 +291,37 @@ def init(language=None):
 
 
 def get_available_languages(domain):
-    """Returns a list of available translations for a given gettext domain.
+    """Returns a set of available translations for a given gettext domain.
 
     Args:
         domain (str)
     Returns:
-        List[text_type]
+        Set[str]
     """
 
-    locale_dir = gettext.bindtextdomain(domain)
-    if locale_dir is None:
-        return []
+    langs = set(["C"])
 
-    try:
-        entries = os.listdir(locale_dir)
-    except OSError:
-        return []
+    for locale_dir in iter_locale_dirs():
+        try:
+            entries = os.listdir(locale_dir)
+        except OSError:
+            continue
+
+        for lang in entries:
+            mo_path = os.path.join(
+                locale_dir, lang, "LC_MESSAGES", "%s.mo" % domain)
+            if os.path.exists(mo_path):
+                langs.add(fsn2text(path2fsn(lang)))
 
-    langs = [u"C"]
-    for lang in entries:
-        mo_path = os.path.join(
-            locale_dir, lang, "LC_MESSAGES", "%s.mo" % domain)
-        if os.path.exists(mo_path):
-            langs.append(fsn2text(path2fsn(lang)))
     return langs
 
 
 def _(message):
     """
     Args:
-        message (text_type)
+        message (str)
     Returns:
-        text_type
+        str
 
     Lookup the translation for message
     """
@@ -334,23 +333,23 @@ def _(message):
 def N_(message):
     """
     Args:
-        message (text_type)
+        message (str)
     Returns:
-        text_type
+        str
 
     Only marks a string for translation
     """
 
-    return text_type(message)
+    return str(message)
 
 
 def C_(context, message):
     """
     Args:
-        context (text_type)
-        message (text_type)
+        context (str)
+        message (str)
     Returns:
-        text_type
+        str
 
     Lookup the translation for message for a context
     """
@@ -362,11 +361,11 @@ def C_(context, message):
 def ngettext(singular, plural, n):
     """
     Args:
-        singular (text_type)
-        plural (text_type)
+        singular (str)
+        plural (str)
         n (int)
     Returns:
-        text_type
+        str
 
     Returns the translation for a singular or plural form depending
     on the value of n.
@@ -383,12 +382,12 @@ def numeric_phrase(singular, plural, n, template_var=None):
     This is added to custom gettext keywords to allow us to use as-is.
 
     Args:
-        singular (text_type)
-        plural (text_type)
+        singular (str)
+        plural (str)
         n (int)
-        template_var (text_type)
+        template_var (str)
     Returns:
-        text_type
+        str
 
     For example,
 
@@ -397,7 +396,7 @@ def numeric_phrase(singular, plural, n, template_var=None):
     `"Add 12,345 songs"`
     (in `en_US` locale at least)
     """
-    num_text = locale_format('%d', n, grouping=True)
+    num_text = locale.format_string('%d', n, grouping=True)
     if not template_var:
         template_var = '%d'
         replacement = '%s'
@@ -407,19 +406,19 @@ def numeric_phrase(singular, plural, n, template_var=None):
         replacement = '%(' + template_var + ')s'
         params = dict()
         params[template_var] = num_text
-    return (ngettext(singular.replace(template_var, replacement),
-            plural.replace(template_var, replacement), n) % params)
+    return (ngettext(singular, plural, n).replace(template_var, replacement) %
+            params)
 
 
 def npgettext(context, singular, plural, n):
     """
     Args:
-        context (text_type)
-        singular (text_type)
-        plural (text_type)
+        context (str)
+        singular (str)
+        plural (str)
         n (int)
     Returns:
-        text_type
+        str
 
     Like ngettext, but with also depends on the context.
     """
