@@ -1,21 +1,36 @@
+# -*- coding: utf-8 -*-
 # Copyright 2012-2013 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+from __future__ import absolute_import
 
 import json
+from collections import namedtuple
+
 from quodlibet.util.dprint import print_d, print_w
+from quodlibet.util.misc import total_ordering
 
 
+@total_ordering
 class JSONObject(object):
     """
     Base class for simple, named data objects
     that can be edited and persisted as JSON.
     """
 
-    # Override this to specify a set of field names, or a map of field: doc
-    # Must include "name" if specified.
+    NAME = ""
+
+    # The format for JSONObject.
+    Field = namedtuple('Field', ['human_name', 'doc'])
+    EMPTY_FIELD = Field(None, None)
+
+    # Override this to specify a set of field names,
+    # or a dict of field: FieldData
+    # Must include "name" if dict is specified.
     FIELDS = {}
 
     @classmethod
@@ -39,17 +54,21 @@ class JSONObject(object):
             return dict([(k, v) for k, v in self.__dict__.items()
                          if self._should_store(k)])
 
-    def field_description(self, name):
-        """Returns the description of field `name` if available, else None"""
+    def field(self, name):
+        """Returns the Field metadata of field `name` if available,
+        or an null / empty one"""
         if isinstance(self.FIELDS, dict):
-            return self.FIELDS.get(name, None)
+            return self.FIELDS.get(name, self.EMPTY_FIELD)
 
     @property
     def json(self):
         return json.dumps(dict(self.data))
 
-    def __cmp__(self, other):
-        return cmp(self.data, other.data)
+    def __eq__(self, other):
+        return self.data == other.data
+
+    def __lt__(self, other):
+        return self.data < other.data
 
     def __str__(self):
         return "<%s '%s' with %s>" % (self.__class__.__name__,
@@ -117,6 +136,7 @@ class JSONObjectDict(dict):
         except AttributeError:
             raise
         json_str = json.dumps(obj_dict, indent=4)
+        json_str = json_str.encode("utf-8")
         if filename:
             try:
                 with open(filename, "wb") as f:
