@@ -2,8 +2,9 @@
 # Copyright 2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from senf import fsnative
 
@@ -34,6 +35,7 @@ class TQuodlibet(TestCase):
         self.assertTrue(isinstance(quodlibet.get_base_dir(), fsnative))
         self.assertTrue(isinstance(quodlibet.get_image_dir(), fsnative))
         self.assertTrue(isinstance(quodlibet.get_user_dir(), fsnative))
+        self.assertTrue(isinstance(quodlibet.get_cache_dir(), fsnative))
 
     def test_get_build_description(self):
         quodlibet.get_build_description()
