@@ -3,8 +3,9 @@
 #                2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from functools import cmp_to_key
 
@@ -227,4 +228,6 @@ class TAlbumBrowser(TestCase):
     def tearDown(self):
         self.bar.disconnect(self._id)
         self.bar.disconnect(self._id2)
+        self.bar.destroy()
+        del self.bar
         config.quit()
