@@ -1,21 +1,23 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gdk, Gtk
-from senf import fsnative, fsn2uri, fsn2bytes
+from senf import fsnative, fsn2uri, fsn2bytes, text2fsn
 
 from quodlibet import app
 from quodlibet import qltk
 from quodlibet.browsers.playlists.prefs import DEFAULT_PATTERN_TEXT
-from quodlibet.browsers.playlists.util import PLAYLISTS, parse_m3u, parse_pls
+from quodlibet.browsers.playlists.util import PLAYLISTS, parse_m3u, \
+    parse_pls, _name_for
 from quodlibet.qltk.songlist import DND_QL
 from quodlibet.util.collection import FileBackedPlaylist
-from tests import TestCase, get_data_path, mkstemp, mkdtemp, _TEMP_DIR, \
+from tests import TestCase, get_data_path, mkdtemp, _TEMP_DIR, \
     init_fake_app, destroy_fake_app
 from tests.gtk_helpers import MockSelData
-from .helper import dummy_path
+from .helper import dummy_path, __, temp_filename
 
 import os
 import shutil
@@ -27,10 +29,10 @@ from quodlibet.formats import AudioFile
 from quodlibet.util.path import mkdir
 from quodlibet.library.librarians import SongLibrarian
 from quodlibet.library.libraries import FileLibrary
-from tests.test_browsers_search import SONGS, TSearchBar
+from tests.test_browsers_search import SONGS
 
 
-class TParsePlaylist(TestCase):
+class ConfigSetupMixin(object):
     def setUp(self):
         quodlibet.config.init()
 
@@ -41,48 +43,44 @@ class TParsePlaylist(TestCase):
 class TParsePlaylistMixin(object):
 
     def test_parse_empty(self):
-        h, name = mkstemp()
-        os.close(h)
-        open(name, "w").close()
-        pl = self.Parse(name)
-        os.unlink(name)
-        self.failUnlessEqual(0, len(pl))
+        with temp_filename() as name:
+            with open(name) as f:
+                pl = self.Parse(f, name)
+        self.failIf(pl)
         pl.delete()
 
     def test_parse_onesong(self):
-        h, name = mkstemp()
-        os.close(h)
-        with open(name, "wb") as f:
-            target = self.prefix
-            target += fsn2bytes(get_data_path("silence-44-s.ogg"), "utf-8")
-            f.write(target)
-        list = self.Parse(name)
-        os.unlink(name)
-        self.failUnlessEqual(len(list), 1)
-        self.failUnlessEqual(list[0]("title"), "Silence")
-        list.delete()
+        with temp_filename() as name:
+            with open(name, "wb") as af:
+                target = self.prefix
+                target += fsn2bytes(get_data_path("silence-44-s.ogg"), "utf-8")
+                af.write(target)
+            with open(name, "rb") as f:
+                pl = self.Parse(f, name)
+        self.failUnlessEqual(len(pl), 1)
+        self.failUnlessEqual(pl[0]("title"), "Silence")
+        pl.delete()
 
     def test_parse_onesong_uri(self):
-        h, name = mkstemp()
-        os.close(h)
         target = get_data_path("silence-44-s.ogg")
         target = fsn2uri(target).encode("ascii")
         target = self.prefix + target
-        with open(name, "wb") as f:
-            f.write(target)
-        list = self.Parse(name)
-        os.unlink(name)
-        self.failUnlessEqual(len(list), 1)
-        self.failUnlessEqual(list[0]("title"), "Silence")
-        list.delete()
+        with temp_filename() as name:
+            with open(name, "wb") as f:
+                f.write(target)
+            with open(name, "rb") as f:
+                pl = self.Parse(f, name)
+        self.failUnlessEqual(len(pl), 1)
+        self.failUnlessEqual(pl[0]("title"), "Silence")
+        pl.delete()
 
 
-class TParseM3U(TParsePlaylist, TParsePlaylistMixin):
+class TParseM3U(TestCase, ConfigSetupMixin, TParsePlaylistMixin):
     Parse = staticmethod(parse_m3u)
     prefix = b""
 
 
-class TParsePLS(TParsePlaylist, TParsePlaylistMixin):
+class TParsePLS(TestCase, ConfigSetupMixin, TParsePlaylistMixin):
     Parse = staticmethod(parse_pls)
     prefix = b"File1="
 
@@ -163,7 +161,7 @@ class TPlaylistIntegration(TestCase):
         self.assertFalse(len(pl))
 
 
-class TPlaylistsBrowser(TSearchBar):
+class TPlaylistsBrowser(TestCase):
     Bar = PlaylistsBrowser
 
     ANOTHER_SONG = AudioFile({
@@ -172,6 +170,7 @@ class TPlaylistsBrowser(TSearchBar):
         "~filename": dummy_path(u"/dev/urandom")})
 
     def setUp(self):
+        self.success = False
         # Testing locally is VERY dangerous without this...
         self.assertTrue(_TEMP_DIR in PLAYLISTS or os.name == "nt",
                         msg="Failing, don't want to delete %s" % PLAYLISTS)
@@ -213,6 +212,17 @@ class TPlaylistsBrowser(TSearchBar):
         PlaylistsBrowser.deinit(self.lib)
         destroy_fake_app()
 
+    def _expected(self, bar, songs, sort):
+        songs.sort()
+        if self.expected is not None:
+            self.failUnlessEqual(self.expected, songs)
+        self.success = True
+
+    def _do(self):
+        while Gtk.events_pending():
+            Gtk.main_iteration()
+        self.failUnless(self.success or self.expected is None)
+
     def test_saverestore(self):
         # Flush previous signals, etc. Hmm.
         self.expected = None
@@ -292,6 +302,37 @@ class TPlaylistsBrowser(TSearchBar):
         self.failUnless(ret, msg="Didn't simulate a delete keypress")
         self.failUnlessEqual(len(first_pl), original_length - 1)
 
+    def test_import(self):
+        pl_name = u"_€3 œufs à Noël"
+        pl = FileBackedPlaylist(_TEMP_DIR, pl_name, None)
+        pl.extend(SONGS)
+        pl.write()
+        new_fn = os.path.splitext(text2fsn(pl.name))[0] + '.m3u'
+        new_path = os.path.join(pl.dir, new_fn)
+        os.rename(pl.filename, new_path)
+        added = self.bar._import_playlists([new_path], self.lib)
+        self.failUnlessEqual(added, 1, msg="Failed to add '%s'" % new_path)
+        os.unlink(new_path)
+        pls = self.bar.playlists()
+        self.failUnlessEqual(len(pls), 3)
+        # Leading underscore makes it always the last entry
+        imported = pls[-1]
+        self.failUnlessEqual(imported.name, pl_name)
+
+        def fns(songs):
+            return [song('~filename') for song in songs]
+        self.failUnlessEqual(fns(imported.songs), fns(pl.songs))
+
     @staticmethod
     def _fake_browser_pack(b):
         app.window.get_child().pack_start(b, True, True, 0)
+
+
+class TPlaylistUtils(TestCase):
+
+    def test_naming(self):
+        self.failUnlessEqual(_name_for('/foo/bar.m3u'), 'bar')
+        self.failUnlessEqual(_name_for('/foo/Will.I.Am.m3u'), 'Will.I.Am')
+
+    def test_naming_default(self):
+        self.failUnlessEqual(_name_for(''), __('New Playlist'))
