@@ -14,7 +14,6 @@ from gi.repository import Gtk
 
 from quodlibet import config
 from quodlibet import app
-from quodlibet.compat import text_type
 
 from quodlibet.commands import registry
 
@@ -29,7 +28,7 @@ class TCommands(TestCase):
         config.quit()
 
     def __send(self, command):
-        command = fsnative(text_type(command))
+        command = fsnative(str(command))
         return registry.handle_line(app, command)
 
     def test_query(self):
@@ -76,7 +75,6 @@ class TCommands(TestCase):
         self.__send("random album")
         self.__send("refresh")
         self.__send("repeat 0")
-        self.__send("set-browser 1")
         self.__send("set-rating 0.5")
         self.__send("show-window")
         self.__send("song-list 1")
@@ -85,6 +83,9 @@ class TCommands(TestCase):
         self.__send("toggle-window")
         self.__send("unqueue /dev/null")
 
+    def test_set_browser(self):
+        self.__send("set-browser 1")
+
     def test_enqueue_files(self):
         songs = [AudioFile({"~filename": fn, "title": fn})
                  for fn in ["one", "two, please", "slash\\.mp3", "four"]]
