@@ -2,8 +2,9 @@
 # Copyright 2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import subprocess
@@ -53,7 +54,7 @@ class _TDesktopFileMixin(object):
 
 
 class TQLDesktopFile(TestCase, _TDesktopFileMixin):
-    PATH = os.path.join(QLDATA_DIR, "quodlibet.desktop.in")
+    PATH = os.path.join(QLDATA_DIR, "io.github.quodlibet.QuodLibet.desktop.in")
 
 
 class TEFDesktopFile(TestCase, _TDesktopFileMixin):
