@@ -18,7 +18,6 @@ from quodlibet.errorreport.logdump import dump_to_disk
 from quodlibet.errorreport.ui import ErrorDialog, SubmitErrorDialog
 from quodlibet.errorreport.main import get_sentry
 from quodlibet.errorreport.sentrywrapper import SentryError, CapturedException
-from quodlibet.compat import text_type
 
 from . import TestCase, mkdtemp
 from .helper import temp_filename
@@ -109,7 +108,7 @@ class Tsentrywrapper(TestCase):
             return
 
         assert isinstance(err, CapturedException)
-        assert isinstance(err.get_report(), text_type)
+        assert isinstance(err.get_report(), str)
 
         err.set_comment(u"foo")
         err.set_comment(u"bar")
