@@ -12,7 +12,6 @@ from contextlib import contextmanager
 from senf import fsnative, fsn2text, bytes2fsn, mkstemp, mkdtemp
 
 from quodlibet import config
-from quodlibet.compat import PY2, text_type, long, listkeys, PY3
 from quodlibet.formats import AudioFile, types as format_types, AudioFileError
 from quodlibet.formats._audio import NUMERIC_ZERO_DEFAULT
 from quodlibet.formats import decode_value, MusicFile, FILESYSTEM_TAGS
@@ -77,9 +76,9 @@ class TAudioFile(TestCase):
     def test_format_type(self):
         for t in format_types:
             i = AudioFile.__new__(t)
-            assert isinstance(i("~format"), text_type)
+            assert isinstance(i("~format"), str)
 
-    def test_tag_text_types(self):
+    def test_tag_strs(self):
         for t in format_types:
             i = AudioFile.__new__(t)
             i["~filename"] = fsnative(u"foo")
@@ -95,7 +94,7 @@ class TAudioFile(TestCase):
                     if name in FILESYSTEM_TAGS:
                         assert isinstance(i(name, fsnative()), fsnative)
                     else:
-                        assert isinstance(i(name), text_type)
+                        assert isinstance(i(name), str)
 
     def test_sort(self):
         l = [self.quux, bar_1_2, bar_2_1, bar_1_1]
@@ -135,21 +134,17 @@ class TAudioFile(TestCase):
         af = AudioFile()
         af[u"foo"] = u"bar"
         assert "foo" in af
-        assert isinstance(listkeys(af)[0], str)
+        assert isinstance(list(af.keys())[0], str)
         af.clear()
         af[u"öäü"] = u"bar"
         assert u"öäü" in af
-        assert isinstance(listkeys(af)[0], text_type)
+        assert isinstance(list(af.keys())[0], str)
 
         with self.assertRaises(TypeError):
             af[42] = u"foo"
 
-        if PY3:
-            with self.assertRaises(TypeError):
-                af[b"foo"] = u"bar"
-        else:
-            with self.assertRaises(ValueError):
-                af[b"\xff"] = u"bar"
+        with self.assertRaises(TypeError):
+            af[b"foo"] = u"bar"
 
     def test_call(self):
         # real keys should lookup the same
@@ -182,7 +177,7 @@ class TAudioFile(TestCase):
     def test_filesize(self):
         self.failUnlessEqual(bar_1_2("~filesize"), "1.00 MB")
         self.failUnlessEqual(bar_1_2("~#filesize"), 1024 ** 2)
-        assert isinstance(bar_1_2("~filesize"), text_type)
+        assert isinstance(bar_1_2("~filesize"), str)
 
     def test_bitrate(self):
         self.assertEqual(bar_1_2("~#bitrate"), 128)
@@ -319,11 +314,11 @@ class TAudioFile(TestCase):
         self.failUnless(", " in bar_2_1.comma("artist"))
 
     def test_comma_filename(self):
-        self.assertTrue(isinstance(bar_1_1.comma("~filename"), text_type))
+        self.assertTrue(isinstance(bar_1_1.comma("~filename"), str))
 
     def test_comma_mountpoint(self):
         assert not bar_1_1("~mountpoint")
-        assert isinstance(bar_1_1.comma("~mountpoint"), text_type)
+        assert isinstance(bar_1_1.comma("~mountpoint"), str)
         assert bar_1_1.comma("~mountpoint") == u""
 
     def test_exist(self):
@@ -596,7 +591,7 @@ class TAudioFile(TestCase):
             lyrics_dir = os.path.dirname(af.lyric_filename)
             mkdir(lyrics_dir)
             with io.open(af.lyric_filename, "w", encoding='utf-8') as lf:
-                lf.write(text_type(lyrics))
+                lf.write(str(lyrics))
             self.failUnlessEqual(af("~lyrics").splitlines(),
                                  lyrics.splitlines())
             os.remove(af.lyric_filename)
@@ -607,7 +602,7 @@ class TAudioFile(TestCase):
         song["~filename"] = fsnative(u"filename")
         song.sanitize()
         assert isinstance(song["~mountpoint"], fsnative)
-        assert isinstance(song.comma("~mointpoint"), text_type)
+        assert isinstance(song.comma("~mointpoint"), str)
 
     def test_sanitize(self):
         q = AudioFile(self.quux)
@@ -626,26 +621,25 @@ class TAudioFile(TestCase):
                        ("performer", "C")])
         self.failUnlessEqual(set(q.list("~performers")), {"A", "B", "C"})
         self.failUnlessEqual(set(q.list("~performers:roles")),
-                             {"A (Vocals)", "B (Guitar)", "C (Performance)"})
+                             {"A (Vocals)", "B (Guitar)", "C"})
 
     def test_performers_multi_value(self):
         q = AudioFile([
             ("performer:vocals", "X\nA\nY"),
             ("performer:guitar", "Y\nB\nA"),
-            ("performer", "C\nF\nB\nA"),
+            ("performer", "C\nB\nA"),
         ])
 
         self.failUnlessEqual(
-            set(q.list("~performer")), {"A", "B", "C", "F", "X", "Y"})
+            set(q.list("~performer")), {"A", "B", "C", "X", "Y"})
 
         self.failUnlessEqual(
             set(q.list("~performer:roles")), {
-                    "A (Guitar, Performance, Vocals)",
-                    "C (Performance)",
-                    "B (Guitar, Performance)",
+                    "A (Guitar, Vocals)",
+                    "C",
+                    "B (Guitar)",
                     "X (Vocals)",
                     "Y (Guitar, Vocals)",
-                    "F (Performance)",
                 })
 
     def test_people(self):
@@ -720,19 +714,6 @@ class TAudioFile(TestCase):
         self.failUnless(
             set(dump.split(b"\n")) == set(n.to_dump().split(b"\n")))
 
-    def test_to_dump_long(self):
-        if not PY2:
-            return
-        b = AudioFile(bar_1_1)
-        b["~#length"] = long(200000000000)
-        dump = b.to_dump()
-        num = len(set(bar_1_1.keys()) | NUMERIC_ZERO_DEFAULT)
-        self.failUnlessEqual(dump.count("\n"), num + 2, msg=dump)
-
-        n = AudioFile()
-        n.from_dump(dump)
-        self.failUnless(set(dump.split("\n")) == set(n.to_dump().split("\n")))
-
     def test_to_dump_unicode(self):
         b = AudioFile(bar_1_1)
         b[u"öäü"] = u"öäü"
@@ -1007,7 +988,7 @@ class Tdecode_value(TestCase):
         self.assertEqual(decode_value("~#foo", 0.25), u"0.25")
         self.assertEqual(decode_value("~#foo", 4), u"4")
         self.assertEqual(decode_value("~#foo", "bar"), u"bar")
-        self.assertTrue(isinstance(decode_value("~#foo", "bar"), text_type))
+        self.assertTrue(isinstance(decode_value("~#foo", "bar"), str))
         path = fsnative(u"/foobar")
         self.assertEqual(decode_value("~filename", path), fsn2text(path))
 
