@@ -7,12 +7,12 @@
 from tests import TestCase, get_data_path
 
 import os
+from io import BytesIO
 
 from quodlibet import const
 from quodlibet.formats._image import EmbeddedImage
 from quodlibet.formats.mp3 import MP3File
 from quodlibet.formats.aiff import AIFFFile
-from quodlibet.compat import cBytesIO
 
 import mutagen
 
@@ -83,7 +83,7 @@ class TID3ImagesMixin(object):
         self.assertFalse(song.has_images)
 
     def test_set_image(self):
-        fileobj = cBytesIO(b"foo")
+        fileobj = BytesIO(b"foo")
         image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
 
         song = self.KIND(self.filename)
@@ -99,7 +99,7 @@ class TID3ImagesMixin(object):
         f = mutagen.File(self.filename)
         f.delete()
         song = self.KIND(self.filename)
-        fileobj = cBytesIO(b"foo")
+        fileobj = BytesIO(b"foo")
         image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
         song.set_image(image)
 
@@ -177,18 +177,21 @@ class TID3FileMixin(object):
                    text=u'lyrics with non-empty lang'))
         f.save()
 
-        f = self.KIND(self.filename)
-        self.failUnlessEqual(f['lyrics'], u'lyrics')
-        f['lyrics'] = u'modified lyrics'
-        f.write()
-
         f = mutagen.File(self.filename)
-        self.failUnlessEqual(f.tags[u'USLT::\x00\x00\x00'], u'modified lyrics')
+        self.failUnlessEqual(f.tags[u'USLT::\x00\x00\x00'], u'lyrics')
         self.failUnlessEqual(f.tags[u'USLT:desc:\x00\x00\x00'],
                              u'lyrics with non-empty desc')
         self.failUnlessEqual(f.tags[u'USLT::xyz'],
                              u'lyrics with non-empty lang')
 
+        f = self.KIND(self.filename)
+        self.failUnlessEqual(sorted(f['lyrics'].split('\n')),
+                             sorted([u'lyrics',
+                                     u'lyrics with non-empty lang',
+                                     u'lyrics with non-empty desc']))
+        f['lyrics'] = u'modified lyrics'
+        f.write()
+
         f = self.KIND(self.filename)
         self.failUnlessEqual(f['lyrics'], u'modified lyrics')
         del f['lyrics']
@@ -197,10 +200,6 @@ class TID3FileMixin(object):
         f = mutagen.File(self.filename)
         self.failIf('USLT' in f.tags,
                     'There should be no USLT tag when lyrics were deleted')
-        self.failUnlessEqual(f.tags[u'USLT:desc:\x00\x00\x00'],
-                             u'lyrics with non-empty desc')
-        self.failUnlessEqual(f.tags[u'USLT::xyz'],
-                             u'lyrics with non-empty lang')
 
         f = self.KIND(self.filename)
         self.failIf('lyrics' in f,
