@@ -31,3 +31,6 @@ class TAIFFFile(TestCase):
 
     def test_channels(self):
         assert self.song("~#channels") == 1
+
+    def test_samplerate(self):
+        assert self.song("~#samplerate") == 8000
