@@ -7,12 +7,12 @@
 from tests import TestCase, get_data_path
 
 import os
+from io import BytesIO
 
 import mutagen
 
 from mutagen.apev2 import BINARY, APEValue
 
-from quodlibet.compat import cBytesIO
 from quodlibet.formats.monkeysaudio import MonkeysAudioFile
 from quodlibet.formats.mpc import MPCFile
 from quodlibet.formats.wavpack import WavpackFile
@@ -135,6 +135,24 @@ class TMAFile(TestCase, TAPEv2FileMixin):
     def test_channels(self):
         assert self.s("~#channels") == 2
 
+    def test_samplerate(self):
+        assert self.s("~#samplerate") == 44100
+
+    def test_bitdepth(self):
+        assert self.s("~#bitdepth") == 16
+
+
+def test_ma_file_old():
+    s = MonkeysAudioFile(get_data_path('mac-396.ape'))
+
+    assert s("~format") == "Monkey's Audio"
+    assert s("~codec") == "Monkey's Audio"
+    assert s("~encoding") == ""
+    assert s("~#channels") == 2
+    assert s("~#samplerate") == 44100
+    # depends on the mutagen version
+    assert s("~#bitdepth", 0) in (0, 16)
+
 
 class TWavpackFileAPEv2(TestCase, TAPEv2FileMixin):
 
@@ -188,7 +206,7 @@ class TWvCoverArt(TestCase):
         self.s.clear_images()
 
     def test_set_image(self):
-        fileobj = cBytesIO(b"foo")
+        fileobj = BytesIO(b"foo")
         image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
         self.s.set_image(image)
         self.assertTrue(self.s.has_images)
@@ -201,7 +219,7 @@ class TWvCoverArt(TestCase):
     def test_set_image_no_tag(self):
         m = mutagen.apev2.APEv2(self.f)
         m.delete()
-        fileobj = cBytesIO(b"foo")
+        fileobj = BytesIO(b"foo")
         image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
         self.s.set_image(image)
         images = self.s.get_images()
