@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase, skipUnless, get_data_path
 
@@ -14,10 +15,10 @@ class TModFile(TestCase):
         self.song = ModFile(get_data_path('empty.xm'))
 
     def test_length(self):
-        self.failUnlessEqual(0, self.song("~#length", 0))
+        self.failUnlessEqual(self.song("~#length", 0), 0)
 
     def test_title(self):
-        self.failUnlessEqual("test song", self.song["title"])
+        self.failUnlessEqual(self.song["title"], "test song")
 
     def test_format_codec(self):
         self.assertEqual(self.song("~format"), "MOD/XM/IT")
