@@ -10,7 +10,6 @@ import os
 
 from tests import TestCase, get_data_path
 from quodlibet.formats.wav import WAVEFile
-from quodlibet.compat import text_type
 
 
 class TWAVEFile(TestCase):
@@ -20,7 +19,7 @@ class TWAVEFile(TestCase):
 
     def test_title_tag(self):
         self.assertEqual(self.song["title"], "test")
-        self.assertTrue(isinstance(self.song["title"], text_type))
+        self.assertTrue(isinstance(self.song["title"], str))
 
     def test_length(self):
         self.failUnlessAlmostEqual(self.song("~#length"), 0.227, 2)
@@ -28,6 +27,12 @@ class TWAVEFile(TestCase):
     def test_channels(self):
         assert self.song("~#channels") == 1
 
+    def test_samplerate(self):
+        assert self.song("~#samplerate") == 11025
+
+    def test_bitdepth(self):
+        assert self.song("~#bitdepth") == 8
+
     def test_write(self):
         self.song.write()
 
