@@ -7,13 +7,13 @@
 # (at your option) any later version.
 
 import os
+from io import BytesIO
 
 from mutagen import asf
 
 from tests import TestCase, get_data_path
 from quodlibet.formats.wma import WMAFile, unpack_image, pack_image
 from quodlibet.formats._image import APICType, EmbeddedImage
-from quodlibet.compat import cBytesIO
 
 from .helper import get_temp_copy
 
@@ -63,6 +63,11 @@ class TWMAFile(TestCase):
         self.assertEqual(self.song2("~#bitrate"), 38)
         self.assertEqual(self.song3("~#bitrate"), 5)
 
+    def test_sample_rate(self):
+        assert self.song("~#samplerate") == 48000
+        assert self.song2("~#samplerate") == 44100
+        assert self.song3("~#samplerate") == 8000
+
     def test_write(self):
         self.song.write()
         self.song2.write()
@@ -179,7 +184,7 @@ class TWMAFile(TestCase):
         self.song.clear_images()
 
     def test_set_image(self):
-        fileobj = cBytesIO(b"foo")
+        fileobj = BytesIO(b"foo")
         image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
         self.assertFalse(self.song.has_images)
         self.song.set_image(image)
