@@ -2,8 +2,9 @@
 # Copyright 2012 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -16,5 +17,9 @@ class TIconTheme(TestCase):
         theme = Gtk.IconTheme.get_default()
         theme.append_search_path(quodlibet.get_image_dir())
 
-        for i in ["quodlibet", "exfalso", "quodlibet-missing-cover"]:
+        for i in [
+            "io.github.quodlibet.QuodLibet",
+            "exfalso",
+            "quodlibet-missing-cover"
+        ]:
             self.failUnless(theme.has_icon(i))
