@@ -10,6 +10,7 @@ from tests.helper import ListWithUnused as L
 import os
 import re
 
+import pytest
 try:
     import polib
 except ImportError:
@@ -17,7 +18,6 @@ except ImportError:
 
 import quodlibet
 from quodlibet.util import get_module_dir
-from quodlibet.util.path import iscommand
 from quodlibet.util.string.titlecase import human_title
 from gdist import gettextutil
 
@@ -26,6 +26,14 @@ QL_BASE_DIR = os.path.dirname(get_module_dir(quodlibet))
 PODIR = os.path.join(QL_BASE_DIR, "po")
 
 
+def has_gettext_util():
+    try:
+        gettextutil.check_version()
+    except gettextutil.GettextError:
+        return False
+    return True
+
+
 class MissingTranslationsException(Exception):
     def __init__(self, missing):
         msg = ("No reference in POTFILES.in to: " +
@@ -33,6 +41,12 @@ class MissingTranslationsException(Exception):
         super(MissingTranslationsException, self).__init__(msg)
 
 
+@pytest.mark.skipif(not has_gettext_util(), reason="no gettext")
+def test_potfile_format():
+    with gettextutil.create_pot(PODIR, strict=True) as pot_path:
+        gettextutil.check_pot(pot_path)
+
+
 class TPOTFILESIN(TestCase):
 
     def test_no_extra_entries(self):
@@ -43,24 +57,20 @@ class TPOTFILESIN(TestCase):
                 assert os.path.isfile(path), \
                     "Can't read '%s' from POTFILES.in" % path
 
+    @pytest.mark.skipif(not has_gettext_util(), reason="no gettext")
     def test_missing(self):
-        try:
-            gettextutil.check_version()
-        except gettextutil.GettextError:
-            return
-
-        results = gettextutil.get_missing(PODIR, "quodlibet")
+        results = gettextutil.get_missing(PODIR)
         if results:
             raise MissingTranslationsException(results)
 
 
 @skipUnless(polib, "polib not found")
+@pytest.mark.skipif(not has_gettext_util(), reason="no gettext")
 class TPot(TestCase):
 
     @classmethod
     def setUpClass(cls):
-        gettextutil.check_version()
-        with gettextutil.create_pot(PODIR, "quodlibet") as pot_path:
+        with gettextutil.create_pot(PODIR, strict=True) as pot_path:
             cls.pot = polib.pofile(pot_path)
 
     def conclude(self, fails, reason):
@@ -236,36 +246,31 @@ class TPot(TestCase):
 
 class POMixin(object):
 
+    @pytest.mark.skipif(not has_gettext_util(), reason="no gettext")
     def test_pos(self):
-        if not iscommand("msgfmt"):
-            return
-
-        po_path = os.path.join(PODIR, "%s.po" % self.lang)
-        self.failIf(os.system(
-            "msgfmt -c -o /dev/null %s > /dev/null" % po_path))
-        try:
-            os.unlink("messages.mo")
-        except OSError:
-            pass
+        po_path = gettextutil.get_po_path(PODIR, self.lang)
+        gettextutil.check_po(po_path)
 
     def test_gtranslator_blows_goats(self):
-        for line in open(os.path.join(PODIR, "%s.po" % self.lang), "rb"):
-            if line.strip().startswith(b"#"):
-                continue
-            self.failIf(b"\xc2\xb7" in line,
-                        "Broken GTranslator copy/paste in %s:\n%r" % (
-                self.lang, line))
+        with open(os.path.join(PODIR, "%s.po" % self.lang), "rb") as h:
+            for line in h:
+                if line.strip().startswith(b"#"):
+                    continue
+                self.failIf(b"\xc2\xb7" in line,
+                            "Broken GTranslator copy/paste in %s:\n%r" % (
+                    self.lang, line))
 
     def test_gtk_stock_items(self):
-        for line in open(os.path.join(PODIR, "%s.po" % self.lang), "rb"):
-            if line.strip().startswith(b'msgstr "gtk-'):
-                parts = line.strip().split()
-                value = parts[1].strip('"')[4:]
-                self.failIf(value and value not in [
-                    b'media-next', b'media-previous', b'media-play',
-                    b'media-pause'],
-                            "Invalid stock translation in %s\n%s" % (
-                    self.lang, line))
+        with open(os.path.join(PODIR, "%s.po" % self.lang), "rb") as h:
+            for line in h:
+                if line.strip().startswith(b'msgstr "gtk-'):
+                    parts = line.strip().split()
+                    value = parts[1].strip('"')[4:]
+                    self.failIf(value and value not in [
+                        b'media-next', b'media-previous', b'media-play',
+                        b'media-pause'],
+                                "Invalid stock translation in %s\n%s" % (
+                        self.lang, line))
 
     def conclude(self, fails, reason):
         if fails:
