@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase
 
@@ -16,6 +17,13 @@ from quodlibet.plugins import PluginManager
 from tests.gtk_helpers import MockSelData
 
 
+def test_is_instance_of_gtype_name():
+    assert qltk.is_instance_of_gtype_name(Gtk.Button(), "GtkButton")
+    assert qltk.is_instance_of_gtype_name(Gtk.Button(), "GtkWidget")
+    assert not qltk.is_instance_of_gtype_name(Gtk.Button(), "GtkLabel")
+    assert not qltk.is_instance_of_gtype_name(Gtk.Button(), "NopeNopeNope")
+
+
 class TQltk(TestCase):
     def test_none(self):
         self.failUnless(qltk.get_top_parent(None) is None)
@@ -114,9 +122,10 @@ class TQltk(TestCase):
     def test_show_uri_with_existing_window(self):
         PluginManager.instance = PluginManager()
         # Force an instance
-        PluginWindow()
+        win = PluginWindow()
         qltk.show_uri("foo", "quodlibet:///prefs/plugins/Squeezebox Output")
         # TODO: proper assertions, etc
+        win.destroy()
 
 
 class Tselection_data(TestCase):
