@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase
 
@@ -75,3 +76,4 @@ class TFilterPluginBox(TestCase):
         handler = EditingPluginHandler()
         x = FilterPluginBox(handler)
         self.assertEqual(x.filters, [])
+        x.destroy()
