@@ -9,7 +9,6 @@ from .helper import visible
 
 from quodlibet.qltk.entry import ValidatingEntry, UndoEntry, Entry
 from quodlibet.query._query import Query
-from quodlibet.compat import text_type
 import quodlibet.config
 
 
@@ -48,7 +47,7 @@ class TValidatingEntry(TestCase):
         entry = ValidatingEntry(valid)
         entry.set_text("foo")
         self.assertEqual(x, [u"foo"])
-        self.assertTrue(isinstance(x[0], text_type))
+        self.assertTrue(isinstance(x[0], str))
 
     def tearDown(self):
         self.entry.destroy()
