@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 from senf import fsnative
@@ -188,15 +189,12 @@ class TSongList(TestCase):
         sel.select_all()
         self.assertTrue(self.songlist.Menu("foo", browser, library))
 
-    def test_get_columns_migrates(self):
+    def test_get_columns_migrated(self):
         self.failIf(config.get("settings", "headers", None))
-        self.failIf(config.get("settings", "columns", None))
-
-        headers = "~album ~#replaygain_track_gain foobar"
-        config.set("settings", "headers", headers)
-        columns = get_columns()
-        self.failUnlessEqual(columns, ["~album", "~#replaygain_track_gain",
-                                       "foobar"])
+        columns = "~album,~#replaygain_track_gain,foobar"
+        config.set("settings", "columns", columns)
+        self.failUnlessEqual(get_columns(),
+                             ["~album", "~#replaygain_track_gain", "foobar"])
         self.failIf(config.get("settings", "headers", None))
 
     def test_get_set_columns(self):
