@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase
 from .helper import visible
@@ -14,6 +15,9 @@ from quodlibet.qltk.songmodel import PlaylistModel
 from quodlibet.formats import AudioFile
 import quodlibet.config
 
+import datetime
+import time
+
 
 class TSongListColumns(TestCase):
     def setUp(self):
@@ -84,3 +88,30 @@ class TSongListColumns(TestCase):
     def test_people(self):
         column = create_songlist_column("~people")
         self._render_column(column)
+
+    def test_custom_datecol_format(self):
+        format = "%Y%m%d %H:%M:%S PLAINTEXT"
+        quodlibet.config.settext("settings", "datecolumn_timestamp_format",
+                                 format)
+
+        d = datetime.datetime(year=1999, month=5, day=1,
+                              hour=23, minute=11, second=59)
+        stamp = int(time.mktime(d.timetuple()))
+        column = create_songlist_column("~#added")
+        text = self._render_column(column, **{"~#added": stamp})
+        self.assertEqual(text, "19990501 23:11:59 PLAINTEXT")
+
+    def test_nonconfigured_datecol_format(self):
+        # make sure config option is unset by default
+        text = quodlibet.config.gettext("settings",
+                                        "datecolumn_timestamp_format")
+        self.assertEqual(text, "")
+
+        # make sure unset config option does not result in the
+        # behaviour for testcase for set option above
+        d = datetime.datetime(year=1999, month=5, day=1,
+                              hour=23, minute=11, second=59)
+        stamp = int(time.mktime(d.timetuple()))
+        column = create_songlist_column("~#added")
+        text = self._render_column(column, **{"~#added": stamp})
+        self.assertNotEqual(text, "19990501 23:11:59 PLAINTEXT")
