@@ -11,7 +11,6 @@ import os
 from senf import fsnative
 
 from quodlibet.util.tagsfrompath import TagsFromPattern
-from quodlibet.compat import iteritems
 
 
 class TTagsFromPattern(TestCase):
@@ -36,7 +35,7 @@ class TTagsFromPattern(TestCase):
         from quodlibet import formats
         pat = TagsFromPattern('<tracknumber>. <title>')
         tracktitle = {'tracknumber': '01', 'title': 'Title'}
-        for ext, kind in iteritems(formats.loaders):
+        for ext, kind in formats.loaders.items():
             f = formats._audio.AudioFile()
             if not isinstance(kind, type):
                 continue
