@@ -13,7 +13,6 @@ from tests import TestCase, get_data_path, skipUnless
 from quodlibet.util.path import normalize_path
 from quodlibet.util import is_wine
 from quodlibet.util import windows
-from quodlibet.compat import text_type
 
 
 @skipUnless(os.name == "nt", "Wrong platform")
@@ -21,34 +20,34 @@ class TWindows(TestCase):
 
     def test_dir_funcs(self):
         d = windows.get_personal_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
         d = windows.get_appdata_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
         d = windows.get_desktop_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
         d = windows.get_music_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
         d = windows.get_profile_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
         d = windows.get_links_dir()
-        self.assertTrue(d is None or isinstance(d, text_type))
+        self.assertTrue(d is None or isinstance(d, str))
 
     def test_get_link_target(self):
         path = get_data_path("test.lnk")
         d = windows.get_link_target(path)
-        self.assertTrue(isinstance(d, text_type))
+        self.assertTrue(isinstance(d, str))
         self.assertEqual(
             normalize_path(d), normalize_path(u"C:\\Windows\\explorer.exe"))
 
     def test_get_link_target_unicode(self):
         path = get_data_path("test2.lnk")
         d = windows.get_link_target(path)
-        self.assertTrue(isinstance(d, text_type))
+        self.assertTrue(isinstance(d, str))
         if is_wine():
             # wine doesn't support unicode paths here..
             self.assertEqual(os.path.basename(d), u"\xe1??.txt")
